@@ -28,16 +28,10 @@
 
 //#define OPL_DEBUG_TRACE
 
-#if (defined(__i386__) || defined(__x86_64__)) && defined(HAVE_IOPERM)
-extern opl_driver_t opl_linux_driver;
+#ifdef EMSCRIPTEN
+#include <emscripten.h>
 #endif
-#if defined(HAVE_LIBI386) || defined(HAVE_LIBAMD64)
-extern opl_driver_t opl_openbsd_driver;
-#endif
-#ifdef _WIN32
-extern opl_driver_t opl_win32_driver;
-#endif
-extern opl_driver_t opl_sdl_driver;
+
 
 static opl_driver_t *drivers[] =
 {
@@ -473,6 +467,8 @@ static void DelayCallback(void *_delay_data)
     SDL_UnlockMutex(delay_data->mutex);
 }
 
+// Delay for specified number of microseconds after OPL subsystem is initialized
+
 void OPL_Delay(uint64_t us)
 {
     delay_data_t delay_data;
@@ -485,6 +481,10 @@ void OPL_Delay(uint64_t us)
     // Create a callback that will signal this thread after the
     // specified time.
 
+    // Note that this is not just a simple time-based delay, it will ensure
+    // that the OPL system is initialized and the queue has begun processing
+    // before releasing the mutex lock
+
     delay_data.finished = 0;
     delay_data.mutex = SDL_CreateMutex();
     delay_data.cond = SDL_CreateCond();
@@ -498,6 +498,10 @@ void OPL_Delay(uint64_t us)
     while (!delay_data.finished)
     {
         SDL_CondWait(delay_data.cond, delay_data.mutex);
+#ifdef EMSCRIPTEN
+        // Use async sleep to avoid locking browser main thread
+        emscripten_sleep(us / 1000);
+#endif
     }
 
     SDL_UnlockMutex(delay_data.mutex);
