@@ -204,6 +204,30 @@ static registry_value_t root_path_keys[] =
         "PATH",
     },
 
+    // [crispy] DOOM Unity port (not Chocolate Doom compatible)
+
+    {
+        HKEY_LOCAL_MACHINE,
+        SOFTWARE_KEY "\\GOG.com\\Games\\2015545325",
+        "PATH"
+    },
+
+    // [crispy] DOOM II Unity port (not Chocolate Doom compatible)
+
+    {
+        HKEY_LOCAL_MACHINE,
+        SOFTWARE_KEY "\\GOG.com\\Games\\1426071866",
+        "PATH"
+    },
+
+    // [crispy] DOOM + DOOM II (not Chocolate Doom compatible)
+
+    {
+        HKEY_LOCAL_MACHINE,
+        SOFTWARE_KEY "\\GOG.com\\Games\\1413291984",
+        "PATH"
+    },
+
     // Strife: Veteran Edition
 
     {
@@ -235,19 +259,29 @@ static registry_value_t root_path_keys[] =
         SOFTWARE_KEY "\\GOG.com\\Games\\1983497091",
         "PATH",
     },
+
+    // Heretic + Hexen Rerelease
+
+    {
+        HKEY_LOCAL_MACHINE,
+        SOFTWARE_KEY "\\GOG.com\\Games\\1776058590",
+        "PATH"
+    },
 };
 
 // Subdirectories of the above install path, where IWADs are installed.
 
 static char *root_path_subdirs[] =
 {
-    ".",
+    ".", // [crispy] moved to top, so reworked IWADs will be found before the legacy DOS ones
     "Doom2",
     "Final Doom",
     "Ultimate Doom",
     "Plutonia",
     "TNT",
     "base\\wads",
+    "dos\\base\\heretic",
+    "dos\\base\\hexen",
 };
 
 // Location where Steam is installed
@@ -275,6 +309,20 @@ static char *steam_install_subdirs[] =
 
     "steamapps\\common\\DOOM 3 BFG Edition\\base\\wads",
 
+    // [crispy] Doom 1 + Doom 2 (not Chocolate Doom compatible):
+
+    "steamapps\\common\\Doom 2\\rerelease\\DOOM II_Data\\StreamingAssets",
+    "steamapps\\common\\Ultimate Doom\\rerelease",
+    "steamapps\\common\\Ultimate Doom\\rerelease\\DOOM_Data\\StreamingAssets",
+
+    // From Heretic + Hexen Rerelease:
+
+    "steamapps\\common\\Heretic + Hexen",
+    "steamapps\\common\\Heretic + Hexen\\base\\heretic",
+    "steamapps\\common\\Heretic + Hexen\\base\\hexen",
+    "steamapps\\common\\Heretic + Hexen\\dos\\base\\heretic",
+    "steamapps\\common\\Heretic + Hexen\\dos\\base\\hexen",
+
     // From Strife: Veteran Edition:
 
     "steamapps\\common\\Strife",
@@ -721,6 +769,11 @@ static void AddSteamDirs(void)
     AddIWADPath(steampath, "/Heretic Shadow of the Serpent Riders/base");
     AddIWADPath(steampath, "/Hexen/base");
     AddIWADPath(steampath, "/Hexen Deathkings of the Dark Citadel/base");
+    AddIWADPath(steampath, "/Heretic + Hexen");
+    AddIWADPath(steampath, "/Heretic + Hexen/base/heretic");
+    AddIWADPath(steampath, "/Heretic + Hexen/base/hexen");
+    AddIWADPath(steampath, "/Heretic + Hexen/dos/base/heretic");
+    AddIWADPath(steampath, "/Heretic + Hexen/dos/base/hexen");
     AddIWADPath(steampath, "/Strife");
     free(steampath);
 }
