@@ -717,7 +717,20 @@ void TryRunTics (void)
 
     if (new_sync)
     {
+        if (crispy->uncapped)
+        {
+            // decide how many tics to run
+            if (realtics < availabletics-1)
+                counts = realtics+1;
+            else if (realtics < availabletics)
+                counts = realtics;
+            else
+                counts = availabletics;
+        }
+        else
+        {
 	counts = availabletics;
+        }
 
         // [AM] If we've uncapped the framerate and there are no tics
         //      to run, return early instead of waiting around.
