@@ -92,7 +92,7 @@ deh_context_t *DEH_OpenFile(const char *filename)
     FILE *fstream;
     deh_context_t *context;
 
-    fstream = fopen(filename, "r");
+    fstream = M_fopen(filename, "r");
 
     if (fstream == NULL)
         return NULL;
