@@ -26,9 +26,11 @@
 #include "m_argv.h"
 #include "m_config.h"
 #include "m_misc.h"
+#include "p_local.h" // [crispy] kex masterlevels
 #include "w_main.h"
 #include "w_wad.h"
 #include "w_merge.h" // [crispy] W_MergeFile()
+#include "z_zone.h"  // [crispy] kex masterlevels
 
 extern char *iwadfile;
 
@@ -41,6 +43,8 @@ static boolean LoadSigilWad (const char *iwaddir, boolean pwadtexture)
 	char *autoload_dir;
 
 	const char *const sigil_wads[] = {
+		"SIGIL_V1_23_REG.wad",
+		"SIGIL_V1_23.wad",
 		"SIGIL_v1_21.wad",
 		"SIGIL_v1_2.wad",
 		"SIGIL.wad"
@@ -348,6 +352,13 @@ static void CheckLoadNerve (void)
 	static const lump_rename_t nerve_lumps [] = {
 		{"TITLEPIC", "NERVEPIC"},
 		{"INTERPIC", "NERVEINT"},
+		{"M_DOOM",   "M_DOOM_N"},
+		{"DEMO1",    "DEMO1N"},
+		{"DEMO2",    "DEMO2N"},
+		{"DEMO3",    "DEMO3N"},
+		{"RSKY1",    "RSKY1N"},
+		{"RSKY2",    "RSKY2N"},
+		{"RSKY3",    "RSKY3N"},
 	};
 
 	// [crispy] don't load if another PWAD already provides MAP01
@@ -403,7 +414,7 @@ static void CheckLoadNerve (void)
 	{
 		j = W_CheckNumForName(nerve_lumps[i].name);
 
-		if (j != -1 && !strcasecmp(W_WadNameForLump(lumpinfo[j]), "NERVE.WAD"))
+		if (j != -1 && !strcasecmp(W_WadNameForLump(lumpinfo[j]), nerve_basename))
 		{
 			memcpy(lumpinfo[j]->name, nerve_lumps[i].new_name, 8);
 		}
@@ -436,6 +447,63 @@ void D_LoadNerveWad (void)
 	}
 }
 
+// [crispy] check if the single MASTERLEVELS.WAD is the kex 2024 version
+int D_CheckMasterlevelKex (void)
+{
+	int lumpnum;
+	int width = 0;
+	patch_t *patch;
+	static int masterlevels_kex = -1;
+
+	// already checked?
+	if (masterlevels_kex > -1)
+	{
+		return masterlevels_kex;
+	}
+
+	// read width of patch CWILV17
+	lumpnum = W_CheckNumForName("MWILV17");
+	if (lumpnum == -1)
+	{
+		// loaded as PWAD?
+		lumpnum = W_CheckNumForName("CWILV17");
+	}
+
+	if (lumpnum > -1)
+	{
+		patch = W_CacheLumpNum(lumpnum, PU_CACHE);
+		width = patch->width;
+	}
+	else
+	{
+		// something's wrong
+		return masterlevels_kex = false;
+	}
+
+	// read width of patch CWILV14
+	lumpnum = W_CheckNumForName("MWILV14");
+	if (lumpnum == -1)
+	{
+		// loaded as PWAD
+		lumpnum = W_CheckNumForName("CWILV14");
+	}
+	patch = W_CacheLumpNum(lumpnum, PU_CACHE);
+
+	// compare width of patches CWILV17 vs CWILV14
+	// kex: CWILV17:"The Express Elevator\nTo Hell" > CWILV14:"Vesperas"
+	// psn/unity: CWILV17:"Vesperas" < CWILV14:"Mephistos Maosoleum"
+	if (patch != NULL && patch->width < width)
+	{
+		masterlevels_kex = true;
+	}
+	else
+	{
+		masterlevels_kex = false;
+	}
+
+	return masterlevels_kex;
+}
+
 // [crispy] check if the single MASTERLEVELS.WAD is already loaded as a PWAD
 static boolean CheckMasterlevelsLoaded (void)
 {
@@ -447,6 +515,7 @@ static boolean CheckMasterlevelsLoaded (void)
 	    !strcasecmp(W_WadNameForLump(lumpinfo[j]), "MASTERLEVELS.WAD"))
 	{
 		gamemission = pack_master;
+		D_CheckMasterlevelKex();
 
 		return true;
 	}
@@ -457,6 +526,13 @@ static boolean CheckMasterlevelsLoaded (void)
 static const lump_rename_t master_lumps [] = {
 	{"TITLEPIC", "MASTRPIC"},
 	{"INTERPIC", "MASTRINT"},
+	{"M_DOOM",   "M_DOOM_M"},
+	{"DEMO1",    "DEMO1M"},
+	{"DEMO2",    "DEMO2M"},
+	{"DEMO3",    "DEMO3M"},
+	{"RSKY1",    "RSKY1M"},
+	{"RSKY2",    "RSKY2M"},
+	{"RSKY3",    "RSKY3M"},
 };
 
 // [crispy] auto-load the single MASTERLEVELS.WAD if available
@@ -507,7 +583,7 @@ static boolean CheckLoadMasterlevels (void)
 
 		M_snprintf(lumpname, 9, "CWILV%2.2d", i);
 		j = W_GetNumForName(lumpname);
-		if (!strcasecmp(W_WadNameForLump(lumpinfo[j]), "MASTERLEVELS.WAD"))
+		if (!strcasecmp(W_WadNameForLump(lumpinfo[j]), master_basename))
 		{
 			lumpinfo[j]->name[0] = 'M';
 		}
@@ -523,6 +599,17 @@ static boolean CheckLoadMasterlevels (void)
 		strcat(lumpinfo[j]->name, "M");
 	}
 
+	// [crispy] if MASTERLEVELS.WAD contains TITLEPIC and INTERPIC, rename them
+	for (i = 0; i < arrlen(master_lumps); i++)
+	{
+		j = W_CheckNumForName(master_lumps[i].name);
+
+		if (j != -1 && !strcasecmp(W_WadNameForLump(lumpinfo[j]), master_basename))
+		{
+			memcpy(lumpinfo[j]->name, master_lumps[i].new_name, 8);
+		}
+	}
+
 	// [crispy] load WAD and DEH files from autoload directories
 	if (!M_ParmExists("-noautoload"))
 	{
@@ -537,6 +624,8 @@ static boolean CheckLoadMasterlevels (void)
 	// [crispy] regenerate the hashtable
 	W_GenerateHashTable();
 
+	D_CheckMasterlevelKex();
+
 	return true;
 }
 
