@@ -66,6 +66,8 @@
 
 #include "v_trans.h" // [crispy] colored "invert mouse" message
 
+#include "d_pwad.h" // [crispy] kex secret level
+
 //
 // defaulted values
 //
@@ -873,8 +875,8 @@ static void M_DrawSaveLoadBottomLine(void)
     struct stat st;
     char filedate[32];
 
-    stat(P_SaveGameFile(itemOn), &st);
-
+    if (M_stat(P_SaveGameFile(itemOn), &st) == 0)
+    {
 // [FG] suppress the most useless compiler warning ever
 #if defined(__GNUC__)
 #pragma GCC diagnostic push
@@ -885,6 +887,7 @@ static void M_DrawSaveLoadBottomLine(void)
 #pragma GCC diagnostic pop
 #endif
     M_WriteText(ORIGWIDTH/2-M_StringWidth(filedate)/2, y + 8, filedate);
+    }
   }
 
   dp_translation = NULL;
@@ -1568,7 +1571,7 @@ static void M_DrawCrispness1(void)
     M_DrawCrispnessItem(crispness_uncapped, "Uncapped Framerate", crispy->uncapped, true);
     M_DrawCrispnessNumericItem(crispness_fpslimit, "Framerate Limit", crispy->fpslimit, "None", crispy->uncapped, "35");
     M_DrawCrispnessItem(crispness_vsync, "Enable VSync", crispy->vsync, !force_software_renderer);
-    M_DrawCrispnessItem(crispness_smoothscaling, "Smooth Pixel Scaling", crispy->smoothscaling, !force_software_renderer);
+    M_DrawCrispnessItem(crispness_smoothscaling, "Smooth Pixel Scaling", smooth_pixel_scaling, !force_software_renderer);
 
     M_DrawCrispnessSeparator(crispness_sep_visual, "Visual");
     M_DrawCrispnessMultiItem(crispness_coloredhud, "Colorize HUD Elements", multiitem_coloredhud, crispy->coloredhud, true);
@@ -2228,6 +2231,14 @@ static int G_GotoNextLevel(void)
         doom2_next[1] = 3;
         doom2_next[14] = 16;
         doom2_next[20] = 1;
+        if (D_CheckMasterlevelKex())
+        {
+            // [crispy] kex secret detour
+            doom2_next[17] = 21;
+            doom2_next[20] = 19;
+            doom2_next[18] = 20;
+            doom2_next[19] = 1;
+        }
       }
     }
     else
@@ -2738,7 +2749,7 @@ boolean M_Responder (event_t* ev)
         {
 	    M_StartControlPanel ();
 	    currentMenu = &SoundDef;
-	    itemOn = sfx_vol;
+	    itemOn = currentMenu->lastOn; // [crispy] remember cursor position
 	    S_StartSoundOptional(NULL, sfx_mnuopn, sfx_swtchn); // [NS] Optional menu sounds.
 	    return true;
 	}
@@ -2788,7 +2799,6 @@ boolean M_Responder (event_t* ev)
             I_SetPalette (W_CacheLumpName (DEH_String("PLAYPAL"),PU_CACHE));
 #else
             {
-		extern void R_InitColormaps (void);
 		I_SetPalette (0);
 		R_InitColormaps();
 		inhelpscreens = true;
