@@ -223,7 +223,8 @@ EV_DoLockedDoor
 	if (!p->cards[it_bluecard] && !p->cards[it_blueskull])
 	{
 	    p->message = DEH_String(PD_BLUEO);
-	    S_StartSound(crispy->soundfix ? p->mo : NULL,sfx_oof);
+	    // [NS] Locked door sound.
+	    S_StartSoundOptional(crispy->soundfix ? p->mo : NULL, sfx_locked, sfx_oof);
 	    // [crispy] blinking key or skull in the status bar
 	    p->tryopen[it_bluecard] = KEYBLINKTICS;
 	    return 0;
@@ -235,7 +236,8 @@ EV_DoLockedDoor
 	if (!p->cards[it_redcard] && !p->cards[it_redskull])
 	{
 	    p->message = DEH_String(PD_REDO);
-	    S_StartSound(crispy->soundfix ? p->mo : NULL,sfx_oof);
+	    // [NS] Locked door sound.
+	    S_StartSoundOptional(crispy->soundfix ? p->mo : NULL, sfx_locked, sfx_oof);
 	    // [crispy] blinking key or skull in the status bar
 	    p->tryopen[it_redcard] = KEYBLINKTICS;
 	    return 0;
@@ -248,7 +250,8 @@ EV_DoLockedDoor
 	    !p->cards[it_yellowskull])
 	{
 	    p->message = DEH_String(PD_YELLOWO);
-	    S_StartSound(crispy->soundfix ? p->mo : NULL,sfx_oof);
+	    // [NS] Locked door sound.
+	    S_StartSoundOptional(crispy->soundfix ? p->mo : NULL, sfx_locked, sfx_oof);
 	    // [crispy] blinking key or skull in the status bar
 	    p->tryopen[it_yellowcard] = KEYBLINKTICS;
 	    return 0;
@@ -376,7 +379,8 @@ EV_VerticalDoor
 	if (!player->cards[it_bluecard] && !player->cards[it_blueskull])
 	{
 	    player->message = DEH_String(PD_BLUEK);
-	    S_StartSound(crispy->soundfix ? player->mo : NULL,sfx_oof);
+	    // [NS] Locked door sound.
+	    S_StartSoundOptional(crispy->soundfix ? player->mo : NULL, sfx_locked, sfx_oof);
 	    // [crispy] blinking key or skull in the status bar
 	    player->tryopen[it_bluecard] = KEYBLINKTICS;
 	    return;
@@ -392,7 +396,8 @@ EV_VerticalDoor
 	    !player->cards[it_yellowskull])
 	{
 	    player->message = DEH_String(PD_YELLOWK);
-	    S_StartSound(crispy->soundfix ? player->mo : NULL,sfx_oof);
+	    // [NS] Locked door sound.
+	    S_StartSoundOptional(crispy->soundfix ? player->mo : NULL, sfx_locked, sfx_oof);
 	    // [crispy] blinking key or skull in the status bar
 	    player->tryopen[it_yellowcard] = KEYBLINKTICS;
 	    return;
@@ -407,7 +412,8 @@ EV_VerticalDoor
 	if (!player->cards[it_redcard] && !player->cards[it_redskull])
 	{
 	    player->message = DEH_String(PD_REDK);
-	    S_StartSound(crispy->soundfix ? player->mo : NULL,sfx_oof);
+	    // [NS] Locked door sound.
+	    S_StartSoundOptional(crispy->soundfix ? player->mo : NULL, sfx_locked, sfx_oof);
 	    // [crispy] blinking key or skull in the status bar
 	    player->tryopen[it_redcard] = KEYBLINKTICS;
 	    return;
