@@ -26,6 +26,7 @@
 
 #include "doomdef.h"
 #include "p_local.h"
+#include "d_pwad.h" // [crispy] kex masterlevels
 
 #include "s_sound.h"
 
@@ -180,7 +181,7 @@ boolean P_CheckMeleeRange (mobj_t*	actor)
     pl = actor->target;
     dist = P_AproxDistance (pl->x-actor->x, pl->y-actor->y);
 
-    if (gameversion <= exe_doom_1_2)
+    if (gameversion < exe_doom_1_5)
         range = MELEERANGE;
     else
         range = MELEERANGE-20*FRACUNIT+pl->info->radius;
@@ -958,7 +959,7 @@ void A_SargAttack (mobj_t* actor)
 		
     A_FaceTarget (actor);
 
-    if (gameversion > exe_doom_1_2)
+    if (gameversion >= exe_doom_1_5)
     {
         if (!P_CheckMeleeRange (actor))
             return;
@@ -1730,6 +1731,36 @@ static boolean CheckBossEnd(mobjtype_t motype)
     }
 }
 
+// [crispy] check if the there is a Doom 2 / Masterlevel tag 666 present in map
+boolean P_CheckMapTag666 (void)
+{
+    if (gamemode == commercial)
+    {
+        if (gamemission == pack_master)
+        {
+            if (D_CheckMasterlevelKex())
+            {
+                // kex materlevels.wad
+                return (gamemap == 13 || gamemap == 19 || gamemap == 20);
+            }
+            else
+            {
+                // psn/unity masterlevels.wad
+                return (gamemap == 14 || gamemap == 15 || gamemap == 16);
+            }
+        }
+        else
+        {
+            // other Doom2-based gamemissions
+            return (gamemap == 7);
+        }        
+    }
+    else
+    {
+        return false;
+    }
+}
+
 //
 // A_BossDeath
 // Possibly trigger special effects
@@ -1744,9 +1775,7 @@ void A_BossDeath (mobj_t* mo)
 		
     if ( gamemode == commercial)
     {
-	if (gamemap != 7 &&
-	// [crispy] Master Levels in PC slot 7
-	!(gamemission == pack_master && (gamemap == 14 || gamemap == 15 || gamemap == 16)))
+	if (!P_CheckMapTag666())
 	    return;
 		
 	if ((mo->type != MT_FATSO)
@@ -1789,9 +1818,7 @@ void A_BossDeath (mobj_t* mo)
     // victory!
     if ( gamemode == commercial)
     {
-	if (gamemap == 7 ||
-	// [crispy] Master Levels in PC slot 7
-	(gamemission == pack_master && (gamemap == 14 || gamemap == 15 || gamemap == 16)))
+	if (P_CheckMapTag666())
 	{
 	    if (mo->type == MT_FATSO)
 	    {
