@@ -152,7 +152,7 @@ static const byte redonly[256] =
 {
 	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0,
+	0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 1, 1,
 	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
 	0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
@@ -485,7 +485,9 @@ static const fullbright_t fullbright_doom[] = {
 	{"SW2STON2", DOOM1ONLY, redonly},
 	{"SW2STON2", DOOM2ONLY, greenonly2},
 	{"SW2STON6", DOOM1AND2, redonly},
-	{"SW2STONE", DOOM1AND2, greenonly2},
+	// [crispy] beware!
+	{"SW2STONE", DOOM1ONLY, greenonly1},
+	{"SW2STONE", DOOM2ONLY, greenonly2},
 	{"SW2STRTN", DOOM1AND2, greenonly1},
 	{"SW2TEK",   DOOM1AND2, greenonly1},
 	{"SW2VINE",  DOOM1AND2, greenonly1},
@@ -505,6 +507,9 @@ static const fullbright_t fullbright_doom[] = {
 	{"SW2SATYR", DOOM1AND2, brighttan},
 	{"SW2LION",  DOOM1AND2, brighttan},
 	{"SW2GARG",  DOOM1AND2, brighttan},
+};
+
+static const fullbright_t fullbright_finaldoom[] = {
 	// [crispy] Final Doom textures
 	// TNT - Evilution exclusive
 	{"PNK4EXIT", DOOM2ONLY, redonly},
@@ -649,6 +654,20 @@ static const byte *R_BrightmapForTexName_Doom (const char *texname)
 		}
 	}
 
+	// Final Doom: Plutonia has no exclusive brightmaps
+	if (gamemission == pack_tnt /* || gamemission == pack_plut */ )
+	{
+		for (i = 0; i < arrlen(fullbright_finaldoom); i++)
+		{
+			const fullbright_t *fullbright = &fullbright_finaldoom[i];
+
+			if (!strncasecmp(fullbright->texture, texname, 8))
+			{
+				return fullbright->colormask;
+			}
+		}
+	}
+
 	return nobrightmap;
 }
 
@@ -705,6 +724,10 @@ static const byte *R_BrightmapForSprite_Doom (const int type)
 		{
 			// Armor Bonus
 			case SPR_BON2:
+			{
+				return greenonly1;
+				break;
+			}
 			// Cell Charge
 			case SPR_CELL:
 			{
