@@ -24,11 +24,11 @@
 
 extern void R_InitBrightmaps ();
 
-extern byte *(*R_BrightmapForTexName) (const char *texname);
-extern byte *(*R_BrightmapForSprite) (const int type);
-extern byte *(*R_BrightmapForFlatNum) (const int num);
-extern byte *(*R_BrightmapForState) (const int state);
+extern const byte *(*R_BrightmapForTexName) (const char *texname);
+extern const byte *(*R_BrightmapForSprite) (const int type);
+extern const byte *(*R_BrightmapForFlatNum) (const int num);
+extern const byte *(*R_BrightmapForState) (const int state);
 
-extern byte **texturebrightmap;
+extern const byte **texturebrightmap;
 
 #endif
