@@ -23,6 +23,7 @@
 #include "deh_main.h"
 #include "i_swap.h"
 #include "i_system.h"
+#include "v_video.h"
 #include "z_zone.h"
 
 
@@ -170,60 +171,6 @@ fixed_t*	spritetopoffset;
 lighttable_t	*colormaps;
 lighttable_t	*pal_color; // [crispy] array holding palette colors for true color mode
 
-// [FG] check if the lump can be a Doom patch
-// taken from PrBoom+ prboom2/src/r_patch.c:L350-L390
-
-static boolean R_IsPatchLump (const int lump)
-{
-  int size;
-  int width, height;
-  const patch_t *patch;
-  boolean result;
-
-  if (lump < 0)
-    return false;
-
-  size = W_LumpLength(lump);
-
-  // minimum length of a valid Doom patch
-  if (size < 13)
-    return false;
-
-  patch = (const patch_t *)W_CacheLumpNum(lump, PU_CACHE);
-
-  // [FG] detect patches in PNG format early
-  if (!memcmp(patch, "\211PNG\r\n\032\n", 8))
-    return false;
-
-  width = SHORT(patch->width);
-  height = SHORT(patch->height);
-
-  result = (height > 0 && height <= 16384 && width > 0 && width <= 16384 && width < size / 4);
-
-  if (result)
-  {
-    // The dimensions seem like they might be valid for a patch, so
-    // check the column directory for extra security. All columns
-    // must begin after the column directory, and none of them must
-    // point past the end of the patch.
-    int x;
-
-    for (x = 0; x < width; x++)
-    {
-      unsigned int ofs = LONG(patch->columnofs[x]);
-
-      // Need one byte for an empty column (but there's patches that don't know that!)
-      if (ofs < (unsigned int)width * 4 + 8 || ofs >= (unsigned int)size)
-      {
-        result = false;
-        break;
-      }
-    }
-  }
-
-  return result;
-}
-
 //
 // MAPTEXTURE_T CACHING
 // When a texture is first needed,
@@ -637,34 +584,63 @@ void R_GenerateLookup (int texnum)
 //
 // R_GetColumn
 //
+
+// [crispy] wrapping column getter function for any non-power-of-two textures
 byte*
 R_GetColumn
 ( int		tex,
   int		col )
 {
-    int		ofs;
-	
-    col &= texturewidthmask[tex];
-    ofs = texturecolumnofs2[tex][col];
+  const int width = texturewidth[tex];
+  const int mask = texturewidthmask[tex];
+  int ofs;
 
-    if (!texturecomposite2[tex])
-	R_GenerateComposite (tex);
+  while (col < 0)
+  {
+    col += width;
+  }
 
-    return texturecomposite2[tex] + ofs;
+  if (mask + 1 == width)
+  {
+    col &= mask;
+  }
+  else
+  {
+    col %= width;
+  }
+
+  ofs  = texturecolumnofs2[tex][col];
+
+  if (!texturecomposite2[tex])
+    R_GenerateComposite(tex);
+
+  return texturecomposite2[tex] + ofs;
 }
 
 // [crispy] wrapping column getter function for composited translucent mid-textures on 2S walls
 byte*
-R_GetColumnMod
+R_GetColumnMasked
 ( int		tex,
   int		col )
 {
-    int		ofs;
+    const int width = texturewidth[tex];
+    const int mask = texturewidthmask[tex];
+    int ofs;
 
     while (col < 0)
-	col += texturewidth[tex];
+    {
+        col += width;
+    }
+
+    if (mask + 1 == width)
+    {
+        col &= mask;
+    }
+    else
+    {
+        col %= width;
+    }
 
-    col %= texturewidth[tex];
     ofs = texturecolumnofs[tex][col];
 
     if (!texturecomposite[tex])
@@ -673,27 +649,6 @@ R_GetColumnMod
     return texturecomposite[tex] + ofs;
 }
 
-// [crispy] wrapping column getter function for non-power-of-two wide sky textures
-byte*
-R_GetColumnMod2
-( int		tex,
-  int		col )
-{
-    int		ofs;
-
-    while (col < 0)
-	col += texturewidth[tex];
-
-    col %= texturewidth[tex];
-    ofs = texturecolumnofs2[tex][col];
-
-    if (!texturecomposite2[tex])
-	R_GenerateComposite(tex);
-
-    return texturecomposite2[tex] + ofs;
-}
-
-
 static void GenerateTextureHashTable(void)
 {
     texture_t **rover;
@@ -874,7 +829,7 @@ void R_InitTextures (void)
 
 	    M_StringCopy(name, pnameslumps[i].name_p + j * 8, sizeof(name));
 	    p = W_CheckNumForName(name);
-	    if (!R_IsPatchLump(p))
+	    if (!V_IsPatchLump(p))
 	        p = -1;
 	    // [crispy] if the name is unambiguous, use the lump we found
 	    patchlookup[k++] = p;
@@ -1189,6 +1144,7 @@ void R_InitColormaps (void)
     //  256 byte align tables.
     lump = W_GetNumForName(DEH_String("COLORMAP"));
     colormaps = W_CacheLumpNum(lump, PU_STATIC);
+    NUMCOLORMAPS = 32; // [crispy] smooth diminishing lighting
 #else
 	int c, i, j = 0;
 	byte r, g, b;
@@ -1196,10 +1152,19 @@ void R_InitColormaps (void)
 	byte *const playpal = W_CacheLumpName("PLAYPAL", PU_STATIC);
 	byte *const colormap = W_CacheLumpName("COLORMAP", PU_STATIC);
 
-	if (!colormaps)
+	// [crispy] Smoothest diminishing lighting.
+	// Compiled in but not enabled TrueColor mode
+	// can't use more than original 32 colormaps.
+	if (crispy->truecolor && crispy->smoothlight)
 	{
-		colormaps = (lighttable_t*) Z_Malloc((NUMCOLORMAPS + 1) * 256 * sizeof(lighttable_t), PU_STATIC, 0);
+		NUMCOLORMAPS = 256;
 	}
+	else
+	{
+		NUMCOLORMAPS = 32;
+	}
+
+	colormaps = I_Realloc(colormaps, (NUMCOLORMAPS + 1) * 256 * sizeof(lighttable_t));
 
 	if (crispy->truecolor)
 	{
