@@ -498,7 +498,7 @@ void R_DrawPlanes (void)
 		{
 		    angle = ((an + xtoviewangle[x])^flip)>>ANGLETOSKYSHIFT;
 		    dc_x = x;
-		    dc_source = R_GetColumnMod2(texture, angle);
+		    dc_source = R_GetColumn(texture, angle);
 		    colfunc ();
 		}
 	    }
