@@ -37,6 +37,7 @@
 
 #include "deh_main.h" // [crispy] for demo footer
 #include "memio.h"
+#include "p_extsaveg.h" // [crispy] for extended savegame information
 
 // Macros
 
@@ -463,6 +464,14 @@ void G_BuildTiccmd(ticcmd_t *cmd, int maketic)
         lspeed = 2;
     }
 
+    // [crispy] add quick 180° reverse
+    if (gamekeydown[key_reverse] || mousebuttons[mousebreverse])
+    {
+        angle += ANG180 >> FRACBITS;
+        gamekeydown[key_reverse] = false;
+        mousebuttons[mousebreverse] = false;
+    }
+
     // [crispy] toggle "always run"
     if (gamekeydown[key_toggleautorun])
     {
@@ -2153,8 +2162,12 @@ void G_DoLoadGame(void)
     {                           // Missing savegame termination marker
         I_Error("Bad savegame");
     }
-}
 
+    // [crispy] read more extended savegame data
+    P_ReadExtendedSaveGameData();
+
+    SV_Close();
+}
 
 /*
 ====================
@@ -2196,9 +2209,14 @@ void G_InitNew(skill_t skill, int episode, int map)
 {
     int i;
     int speed;
-    static const char *skyLumpNames[5] = {
-        "SKY1", "SKY2", "SKY3", "SKY1", "SKY3"
+    // [crispy] Support for sky textures from H+H IWAD.
+    static const char *skyLumpNames[2][5] = {
+        { "SKY1", "SKY2", "SKY3", "SKY1", "SKY3" },
+        { "SKY1", "SKY2", "SKY3", "SKY4", "SKY5" }
     };
+    const boolean RemasterSky = (R_CheckTextureNumForName(DEH_String("SKY4")) != -1)
+                             && (R_CheckTextureNumForName(DEH_String("SKY5")) != -1);
+    const char *ep6Sky = DEH_String(RemasterSky ? "SKY6" : "SKY1");
 
     if (paused)
     {
@@ -2261,11 +2279,11 @@ void G_InitNew(skill_t skill, int episode, int map)
     // Set the sky map
     if (episode > 5)
     {
-        skytexture = R_TextureNumForName(DEH_String("SKY1"));
+        skytexture = R_TextureNumForName(ep6Sky);
     }
     else
     {
-        skytexture = R_TextureNumForName(DEH_String(skyLumpNames[episode - 1]));
+        skytexture = R_TextureNumForName(DEH_String(skyLumpNames[RemasterSky][episode - 1]));
     }
 
 //
@@ -2698,10 +2716,10 @@ static size_t WriteCmdLineLump(MEMFILE *stream)
     return mem_ftell(stream) - pos;
 }
 
-static void WriteFileInfo(const char *name, size_t size, MEMFILE *stream)
+static long WriteFileInfo(const char *name, size_t size, long filepos,
+                          MEMFILE *stream)
 {
     filelump_t fileinfo = { 0 };
-    static long filepos = sizeof(wadinfo_t);
 
     fileinfo.filepos = LONG(filepos);
     fileinfo.size = LONG(size);
@@ -2719,12 +2737,14 @@ static void WriteFileInfo(const char *name, size_t size, MEMFILE *stream)
     mem_fwrite(&fileinfo, 1, sizeof(fileinfo), stream);
 
     filepos += size;
+    return filepos;
 }
 
 static void G_AddDemoFooter(void)
 {
     byte *data;
     size_t size;
+    long filepos;
     char *project_string;
 
     MEMFILE *stream = mem_fopen_write();
@@ -2745,10 +2765,11 @@ static void G_AddDemoFooter(void)
     mem_fwrite(&header, 1, sizeof(header), stream);
     mem_fseek(stream, 0, MEM_SEEK_END);
 
-    WriteFileInfo("PORTNAME", strlen(project_string), stream);
-    WriteFileInfo(NULL, strlen(DEMO_FOOTER_SEPARATOR), stream);
-    WriteFileInfo("CMDLINE", size, stream);
-    WriteFileInfo(NULL, strlen(DEMO_FOOTER_SEPARATOR), stream);
+    filepos = sizeof(wadinfo_t);
+    filepos = WriteFileInfo("PORTNAME", strlen(project_string), filepos, stream);
+    filepos = WriteFileInfo(NULL, strlen(DEMO_FOOTER_SEPARATOR), filepos, stream);
+    filepos = WriteFileInfo("CMDLINE", size, filepos, stream);
+    WriteFileInfo(NULL, strlen(DEMO_FOOTER_SEPARATOR), filepos, stream);
 
     mem_get_buf(stream, (void **)&data, &size);
 
@@ -2878,7 +2899,10 @@ void G_DoSaveGame(void)
     P_ArchiveWorld();
     P_ArchiveThinkers();
     P_ArchiveSpecials();
-    SV_Close(filename);
+    SV_WriteSaveGameEOF();
+    // [crispy] write extended savegame data
+    P_WriteExtendedSaveGameData();
+    SV_Close();
 
     gameaction = ga_nothing;
     savedescription[0] = 0;
