@@ -177,7 +177,11 @@ static const char *NameForMap(int map)
 
 void IN_Start(void)
 {
+#ifndef CRISPY_TRUECOLOR
     I_SetPalette(W_CacheLumpName(DEH_String("PLAYPAL"), PU_CACHE));
+#else
+    I_SetPalette(0);
+#endif
     IN_LoadPics();
     IN_InitStats();
     intermission = true;
@@ -614,28 +618,15 @@ void IN_Drawer(void)
 
 void IN_DrawStatBack(void)
 {
-    int x;
-    int y;
 
     byte *src;
-    byte *dest;
+    pixel_t *dest;
 
     src = W_CacheLumpName(DEH_String("FLOOR16"), PU_CACHE);
     dest = I_VideoBuffer;
 
-    for (y = 0; y < SCREENHEIGHT; y++)
-    {
-        for (x = 0; x < SCREENWIDTH / 64; x++)
-        {
-            memcpy(dest, src + ((y & 63) << 6), 64);
-            dest += 64;
-        }
-        if (SCREENWIDTH & 63)
-        {
-            memcpy(dest, src + ((y & 63) << 6), SCREENWIDTH & 63);
-            dest += (SCREENWIDTH & 63);
-        }
-    }
+    // [crispy] use unified flat filling function
+    V_FillFlat(0, SCREENHEIGHT, 0, SCREENWIDTH, src, dest);
 }
 
 //========================================================================
