@@ -1363,12 +1363,18 @@ typedef enum
     NUMSTATES
 } statenum_t;
 
+
+struct mobj_s;
+struct player_s;
+struct pspdef_s;
+
+
 typedef struct
 {
     spritenum_t sprite;
     int frame;
     int tics;
-    void (*action) ();
+    void (*action) (struct mobj_s *, struct player_s *, struct pspdef_s *);
     statenum_t nextstate;
     int misc1, misc2;
 } state_t;
