@@ -505,6 +505,7 @@ boolean P_GiveArtifact(player_t * player, artitype_t arti, mobj_t * mo)
 void P_SetDormantArtifact(mobj_t * arti)
 {
     arti->flags &= ~MF_SPECIAL;
+    arti->flags |= MF_TRANSLUCENT; // [crispy] artifact pickup translucent
     if (deathmatch && (arti->type != MT_ARTIINVULNERABILITY)
         && (arti->type != MT_ARTIINVISIBILITY))
     {
@@ -525,6 +526,7 @@ void P_SetDormantArtifact(mobj_t * arti)
 
 void A_RestoreArtifact(mobj_t * arti, player_t *player, pspdef_t *psp)
 {
+    arti->flags &= ~MF_TRANSLUCENT; // [crispy] artifact respawn opaque
     arti->flags |= MF_SPECIAL;
     P_SetMobjState(arti, arti->info->spawnstate);
     S_StartSound(arti, sfx_respawn);
@@ -538,6 +540,7 @@ void A_RestoreArtifact(mobj_t * arti, player_t *player, pspdef_t *psp)
 
 void P_HideSpecialThing(mobj_t * thing)
 {
+    thing->flags |= MF_TRANSLUCENT; // [crispy] special translucent
     thing->flags &= ~MF_SPECIAL;
     thing->flags2 |= MF2_DONTDRAW;
     P_SetMobjState(thing, S_HIDESPECIAL1);
@@ -569,6 +572,7 @@ void A_RestoreSpecialThing1(mobj_t * thing, player_t *player, pspdef_t *psp)
 
 void A_RestoreSpecialThing2(mobj_t * thing, player_t *player, pspdef_t *psp)
 {
+    thing->flags &= ~MF_TRANSLUCENT; // [crispy] thing respawn opaque
     thing->flags |= MF_SPECIAL;
     P_SetMobjState(thing, thing->info->spawnstate);
 }
@@ -975,6 +979,11 @@ void P_KillMobj(mobj_t * source, mobj_t * target)
             return;
         }
     }
+
+    // [crispy] Exploding Goo-Pods are translucent
+    if (target->type == MT_POD)
+        target->flags |= MF_TRANSLUCENT;
+
     if (target->health < -(target->info->spawnhealth >> 1)
         && target->info->xdeathstate)
     {                           // Extreme death
