@@ -21,6 +21,7 @@
 #include "doomdef.h"
 #include "i_system.h" // [crispy] I_Realloc()
 #include "m_bbox.h"
+#include "m_misc.h"
 #include "p_local.h"
 
 
@@ -464,6 +465,8 @@ boolean P_BlockThingsIterator(int x, int y, boolean(*func) (mobj_t *))
     if (x < 0 || y < 0 || x >= bmapwidth || y >= bmapheight)
         return true;
 
+    LINKED_LIST_CHECK_NO_CYCLE(mobj_t, blocklinks[y*bmapwidth+x], bnext);
+
     for (mobj = blocklinks[y * bmapwidth + x]; mobj; mobj = mobj->bnext)
         if (!func(mobj))
             return false;
