@@ -41,18 +41,22 @@
 //
 // lighting constants
 //
-#define	LIGHTLEVELS			16
-#define	LIGHTSEGSHIFT		4
-#define	MAXLIGHTSCALE		48
-#define	LIGHTSCALESHIFT		12
-#define	MAXLIGHTZ			128
-#define	LIGHTZSHIFT			20
-#define	NUMCOLORMAPS		32      // number of diminishing
+// [crispy] parameterized for smooth diminishing lighting
+extern int LIGHTLEVELS;
+extern int LIGHTSEGSHIFT;
+extern int LIGHTBRIGHT;
+extern int MAXLIGHTSCALE;
+extern int LIGHTSCALESHIFT;
+extern int MAXLIGHTZ;
+extern int LIGHTZSHIFT;
+// [crispy] parameterized for smooth diminishing lighting
+extern int NUMCOLORMAPS;      // number of diminishing
 #define	INVERSECOLORMAP		32
 
 #define LOOKDIRMIN 110 // [crispy] -110, actually
 #define LOOKDIRMAX 90
 #define LOOKDIRS (LOOKDIRMIN + 1 + LOOKDIRMAX) // [crispy] lookdir range: -110..0..90
+#define TRANSLUCENT_HUD (screenblocks == 14 || screenblocks == 16) // [crispy] determine if translucent hud is selected
 /*
 ==============================================================================
 
@@ -120,6 +124,9 @@ typedef struct
     //      the renderer.
     fixed_t	interpfloorheight;
     fixed_t	interpceilingheight;
+
+    // [crispy] A11Y light level used for rendering
+    short	rlightlevel;
 } sector_t;
 
 typedef struct
@@ -171,6 +178,7 @@ typedef struct
 
     uint32_t length; // [crispy] fix long wall wobble
     angle_t r_angle; // [crispy] recalculated angle used for rendering
+    int fakecontrast;
 } seg_t;
 
 typedef struct
@@ -257,6 +265,11 @@ typedef struct vissprite_s
 
 extern visplane_t *floorplane, *ceilingplane;
 
+typedef struct
+{
+    int l, w, h, loffset, toffset;
+} crosshairpatch_t;
+
 // Sprites are patches with a special naming convention so they can be 
 // recognized by R_InitSprites.  The sprite and frame specified by a 
 // thing_t is range checked at run time.
@@ -342,9 +355,9 @@ extern fixed_t projection;
 extern int validcount;
 
 extern int sscount, linecount, loopcount;
-extern lighttable_t *scalelight[LIGHTLEVELS][MAXLIGHTSCALE];
-extern lighttable_t *scalelightfixed[MAXLIGHTSCALE];
-extern lighttable_t *zlight[LIGHTLEVELS][MAXLIGHTZ];
+extern lighttable_t ***scalelight;
+extern lighttable_t  **scalelightfixed;
+extern lighttable_t ***zlight;
 
 extern int extralight;
 extern lighttable_t *fixedcolormap;
@@ -506,6 +519,7 @@ extern void R_InitColormaps(void);
 #ifdef CRISPY_TRUECOLOR
 extern void R_SetUnderwaterPalette(byte *palette);
 #endif
+extern int R_GetPatchHeight(int texture_num, int patch_index);
 
 //
 // R_things.c
@@ -588,4 +602,7 @@ void R_DrawSpanLow(void);
 void R_InitBuffer(int width, int height);
 void R_InitTranslationTables(void);
 
+extern void (*V_DrawSBPatch)(int x, int y, patch_t *patch); // [crispy] for conditional drawing of status bar elements
+void SB_Translucent(boolean translucent); // [crispy] on/off status bar translucency
+
 #endif // __R_LOCAL__
