@@ -27,9 +27,8 @@
 #include "s_sound.h"
 #include "v_video.h"
 #include "am_map.h"
-#ifdef CRISPY_TRUECOLOR
-#include "v_trans.h" // [crispy] I_BlendDark()
-#endif
+#include "v_trans.h" // [crispy] dp_translation & blend truecolor
+#include "a11y.h" // [crispy] A11Y
 
 // Types
 
@@ -76,6 +75,10 @@ static void CheatSpecHitFunc(player_t *player, Cheat_t *cheat);
 static void CheatNoMomentumFunc(player_t *player, Cheat_t *cheat);
 static void CheatHomDetectFunc(player_t *player, Cheat_t *cheat);
 
+// [crispy] player crosshair functions
+static void HU_DrawCrosshair(void);
+static byte *R_CrosshairColor(void);
+
 // Public Data
 
 boolean DebugSound;             // debug flag for displaying sound info
@@ -90,6 +93,15 @@ static int DisplayTicker = 0;
 // [crispy] for widescreen status bar background
 pixel_t *st_backing_screen;
 
+// [crispy] for conditional drawing of status bar elements
+void (*V_DrawSBPatch)(int x, int y, patch_t *patch) = V_DrawPatch;
+
+// [crispy] on/off status bar translucency
+void SB_Translucent(boolean translucent)
+{
+    V_DrawSBPatch = translucent ? V_DrawTLPatch : V_DrawPatch;
+}
+
 // Private Data
 
 static int HealthMarker;
@@ -129,6 +141,14 @@ int FontBNumBase;
 int spinbooklump;
 int spinflylump;
 
+// [crispy] keep in sync with multiitem_t multiitem_he_crosshairtype[] in mn_menu.c
+static crosshairpatch_t crosshairpatch_m[NUM_HE_CROSSHAIRTYPE] = {
+    {0, 0, 0, 0, 0},
+    {0, 0, 0, 0, 0},
+    {0, 0, 0, 0, 0},
+};
+static crosshairpatch_t *crosshairpatch = crosshairpatch_m;
+
 // Toggle god mode
 cheatseq_t CheatGodSeq = CHEAT("quicken", 0);
 
@@ -270,6 +290,32 @@ void SB_Init(void)
     spinbooklump = W_GetNumForName(DEH_String("SPINBK0"));
     spinflylump = W_GetNumForName(DEH_String("SPFLY0"));
 
+    // [crispy] initialize the crosshair types
+    for (i = 0; i < NUM_HE_CROSSHAIRTYPE; i++)
+    {
+        patch_t *patch = NULL;
+
+        if (i == CROSSHAIRTYPE_HE_DOT)
+        {
+            crosshairpatch[i].l = W_GetNumForName("FONTB28");
+        }
+        else if (i == CROSSHAIRTYPE_HE_CROSS1)
+        {
+            crosshairpatch[i].l = W_GetNumForName("TGLTH0");
+        }
+        else
+        {
+            crosshairpatch[i].l = W_GetNumForName("TGLTF0");
+        }
+
+        patch = W_CacheLumpNum(crosshairpatch[i].l, PU_STATIC);
+
+        crosshairpatch[i].w = SHORT(patch->width) / 2;
+        crosshairpatch[i].h = SHORT(patch->height) / 2;
+        crosshairpatch[i].loffset = SHORT(patch->leftoffset);
+        crosshairpatch[i].toffset = SHORT(patch->topoffset);
+    }
+
     st_backing_screen = (pixel_t *) Z_Malloc(MAXWIDTH * (42 << 1) * sizeof(*st_backing_screen), PU_STATIC, 0);
 }
 
@@ -319,6 +365,11 @@ void SB_Ticker(void)
         }
         HealthMarker += delta;
     }
+    // [crispy] play artifact flash animation independently of framerate
+    if (ArtifactFlash > 0)
+    {
+        ArtifactFlash--;
+    }
     SB_PaletteFlash();
 }
 
@@ -340,30 +391,30 @@ static void DrINumber(signed int val, int x, int y)
     {
         if (val < -9)
         {
-            V_DrawPatch(x + 1, y + 1, W_CacheLumpName(DEH_String("LAME"), PU_CACHE));
+            V_DrawSBPatch(x + 1, y + 1, W_CacheLumpName(DEH_String("LAME"), PU_CACHE));
         }
         else
         {
             val = -val;
-            V_DrawPatch(x + 18, y, PatchINumbers[val]);
-            V_DrawPatch(x + 9, y, PatchNEGATIVE);
+            V_DrawSBPatch(x + 18, y, PatchINumbers[val]);
+            V_DrawSBPatch(x + 9, y, PatchNEGATIVE);
         }
         return;
     }
     if (val > 99)
     {
         patch = PatchINumbers[val / 100];
-        V_DrawPatch(x, y, patch);
+        V_DrawSBPatch(x, y, patch);
     }
     val = val % 100;
     if (val > 9 || oldval > 99)
     {
         patch = PatchINumbers[val / 10];
-        V_DrawPatch(x + 9, y, patch);
+        V_DrawSBPatch(x + 9, y, patch);
     }
     val = val % 10;
     patch = PatchINumbers[val];
-    V_DrawPatch(x + 18, y, patch);
+    V_DrawSBPatch(x + 18, y, patch);
 }
 
 //---------------------------------------------------------------------------
@@ -423,11 +474,11 @@ static void DrSmallNumber(int val, int x, int y)
     if (val > 9)
     {
         patch = PatchSmNumbers[val / 10];
-        V_DrawPatch(x, y, patch);
+        V_DrawSBPatch(x, y, patch);
     }
     val = val % 10;
     patch = PatchSmNumbers[val];
-    V_DrawPatch(x + 4, y, patch);
+    V_DrawSBPatch(x + 4, y, patch);
 }
 
 //---------------------------------------------------------------------------
@@ -450,7 +501,7 @@ static void ShadeLine(int x, int y, int height, int shade)
 #ifndef CRISPY_TRUECOLOR
     shades = colormaps + 9 * 256 + shade * 2 * 256;
 #else
-    shade = 0xFF - (((9 + shade * 2) << 8) / NUMCOLORMAPS);
+    shade = 0xFF - (((9 + shade * 2) << 8) / 32); // [crispy] shade to darkest 32nd COLORMAP row
 #endif
     dest = I_VideoBuffer + y * SCREENWIDTH + x + (WIDESCREENDELTA << crispy->hires);
     while (height--)
@@ -728,13 +779,13 @@ void SB_Drawer(void)
             {
                 if (hitCenterFrame && (frame != 15 && frame != 0))
                 {
-                    V_DrawPatch(spinfly_x, 17,
+                    V_DrawSBPatch(spinfly_x, 17,
                                 W_CacheLumpNum(spinflylump + 15,
                                                 PU_CACHE));
                 }
                 else
                 {
-                    V_DrawPatch(spinfly_x, 17,
+                    V_DrawSBPatch(spinfly_x, 17,
                                 W_CacheLumpNum(spinflylump + frame,
                                                 PU_CACHE));
                     hitCenterFrame = false;
@@ -744,14 +795,14 @@ void SB_Drawer(void)
             {
                 if (!hitCenterFrame && (frame != 15 && frame != 0))
                 {
-                    V_DrawPatch(spinfly_x, 17,
+                    V_DrawSBPatch(spinfly_x, 17,
                                 W_CacheLumpNum(spinflylump + frame,
                                                 PU_CACHE));
                     hitCenterFrame = false;
                 }
                 else
                 {
-                    V_DrawPatch(spinfly_x, 17,
+                    V_DrawSBPatch(spinfly_x, 17,
                                 W_CacheLumpNum(spinflylump + 15,
                                                 PU_CACHE));
                     hitCenterFrame = true;
@@ -779,7 +830,7 @@ void SB_Drawer(void)
             || !(CPlayer->powers[pw_weaponlevel2] & 16))
         {
             frame = (leveltime / 3) & 15;
-            V_DrawPatch(spinbook_x, 17,
+            V_DrawSBPatch(spinbook_x, 17,
                         W_CacheLumpNum(spinbooklump + frame, PU_CACHE));
             BorderTopRefresh = true;
             UpdateState |= I_MESSAGES;
@@ -790,6 +841,15 @@ void SB_Drawer(void)
             UpdateState |= I_MESSAGES;
         }
     }
+
+    // [crispy] draw player crosshair
+    if (crispy->crosshair)
+    {
+        SB_Translucent(crispy->crosshair == CROSSHAIR_HE_TRANSLUCENT);
+        HU_DrawCrosshair();
+        SB_Translucent(TRANSLUCENT_HUD);
+    }
+
 /*
 		if(CPlayer->powers[pw_weaponlevel2] > BLINKTHRESHOLD
 			|| (CPlayer->powers[pw_weaponlevel2]&8))
@@ -816,7 +876,12 @@ void SB_PaletteFlash(void)
 
     CPlayer = &players[consoleplayer];
 
-    if (CPlayer->damagecount)
+    // [crispy] A11Y
+    if (!a11y_palette_changes)
+    {
+        palette = 0;
+    }
+    else if (CPlayer->damagecount)
     {
         palette = (CPlayer->damagecount + 7) >> 3;
         if (palette >= NUMREDPALS)
@@ -908,7 +973,7 @@ void DrawMainBar(void)
         temp = W_GetNumForName(DEH_String("useartia")) + ArtifactFlash - 1;
 
         V_DrawPatch(182, 161, W_CacheLumpNum(temp, PU_CACHE));
-        ArtifactFlash--;
+        // ArtifactFlash--; [crispy] moved to SB_Ticker
         oldarti = -1;           // so that the correct artifact fills in after the flash
         UpdateState |= I_STATBAR;
     }
@@ -1055,15 +1120,139 @@ void DrawFullScreenStuff(void)
     int i;
     int x;
     int temp;
+    int xPosGem2; // [crispy] for intersect detection
+    int xPosKeys; // [crispy] for intersect detection
+    int sboffset; // [crispy] to apply WIDESCREENDELTA
 
     UpdateState |= I_FULLSCRN;
-    if (CPlayer->mo->health > 0)
+
+    // [crispy] check for widescreen HUD
+    if (screenblocks == 12 || screenblocks >= 15)
     {
-        DrBNumber(CPlayer->mo->health, 5, 180);
+        sboffset = WIDESCREENDELTA;
     }
     else
     {
-        DrBNumber(0, 5, 180);
+        sboffset = 0;
+    }
+
+    // [crispy] Crispy Hud
+    if (screenblocks >= 13)
+    {
+        xPosGem2 = 270;
+        xPosKeys = 214 + sboffset;
+
+        // Health
+        temp = CPlayer->mo->health;
+        if (temp > 0)
+        {
+            DrINumber(temp, 5 - sboffset, 180);
+        }
+        else
+        {
+            DrINumber(0, 5 - sboffset, 180);
+        }
+        // Armor
+        DrINumber(CPlayer->armorpoints, 286 + sboffset, 180);
+        // Frags
+        if (deathmatch)
+        {
+            temp = 0;
+            for (i = 0; i < MAXPLAYERS; i++)
+            {
+                if (playeringame[i])
+                {
+                    temp += CPlayer->frags[i];
+                }
+            }
+            DrINumber(temp, 5 - sboffset, 165);
+        }
+        // Items, Itemflash and Selection Bar
+        if (!inventory)
+        {
+            if (ArtifactFlash)
+            {
+                temp = W_GetNumForName(DEH_String("useartia")) + ArtifactFlash - 1;
+                V_DrawSBPatch(243 + sboffset, 171, W_CacheLumpNum(temp, PU_CACHE));
+                ArtifactFlash--;
+            }
+            else if (CPlayer->readyArtifact > 0)
+            {
+                patch = DEH_String(patcharti[CPlayer->readyArtifact]);
+                V_DrawSBPatch(240 + sboffset, 170, W_CacheLumpName(patch, PU_CACHE));
+                DrSmallNumber(CPlayer->inventory[inv_ptr].count, 262 + sboffset, 192);
+            }
+        }
+        else
+        {
+            x = inv_ptr - curpos;
+            for (i = 0; i < 7; i++)
+            {
+                // [crispy] check for translucent HUD
+                SB_Translucent(TRANSLUCENT_HUD);
+                V_DrawSBPatch(50 + i * 31, 168,
+                              W_CacheLumpName(DEH_String("ARTIBOX"), PU_CACHE));
+                SB_Translucent(false); // listed artifacts and selectbox are always opaque
+                if (CPlayer->inventorySlotNum > x + i
+                    && CPlayer->inventory[x + i].type != arti_none)
+                {
+                    patch = DEH_String(patcharti[CPlayer->inventory[x + i].type]);
+                    V_DrawSBPatch(50 + i * 31, 168,
+                                W_CacheLumpName(patch, PU_CACHE));
+                    DrSmallNumber(CPlayer->inventory[x + i].count, 69 + i * 31,
+                                  190);
+                }
+            }
+            V_DrawSBPatch(50 + curpos * 31, 197, PatchSELECTBOX);
+            // [crispy] check for translucent HUD
+            SB_Translucent(TRANSLUCENT_HUD);
+            if (x != 0)
+            {
+                V_DrawSBPatch(38, 167, !(leveltime & 4) ? PatchINVLFGEM1 :
+                            PatchINVLFGEM2);
+            }
+            if (CPlayer->inventorySlotNum - x > 7)
+            {
+                V_DrawSBPatch(xPosGem2, 167, !(leveltime & 4) ?
+                            PatchINVRTGEM1 : PatchINVRTGEM2);
+            }
+            // Check for Intersect
+            if (xPosGem2 + 10 >= xPosKeys)
+            {
+                return; // Stop drawing further widgets
+            }
+        }
+        // Ammo
+        temp = CPlayer->ammo[wpnlev1info[CPlayer->readyweapon].ammo];
+        if (temp && CPlayer->readyweapon > 0 && CPlayer->readyweapon < 7)
+        {
+            V_DrawSBPatch(55 - sboffset, 182,
+                        W_CacheLumpName(DEH_String(ammopic[CPlayer->readyweapon - 1]),
+                                        PU_CACHE));
+            DrINumber(temp, 53 - sboffset, 172);
+        }
+        // Keys
+        if (CPlayer->keys[key_yellow])
+        {
+            V_DrawSBPatch(xPosKeys, 174, W_CacheLumpName(DEH_String("ykeyicon"), PU_CACHE));
+        }
+        if (CPlayer->keys[key_green])
+        {
+            V_DrawSBPatch(xPosKeys, 182, W_CacheLumpName(DEH_String("gkeyicon"), PU_CACHE));
+        }
+        if (CPlayer->keys[key_blue])
+        {
+            V_DrawSBPatch(xPosKeys, 190, W_CacheLumpName(DEH_String("bkeyicon"), PU_CACHE));
+        }
+        return;
+    }
+    if (CPlayer->mo->health > 0)
+    {
+        DrBNumber(CPlayer->mo->health, 5 - sboffset, 180);
+    }
+    else
+    {
+        DrBNumber(0, 5 - sboffset, 180);
     }
     if (deathmatch)
     {
@@ -1075,16 +1264,16 @@ void DrawFullScreenStuff(void)
                 temp += CPlayer->frags[i];
             }
         }
-        DrINumber(temp, 45, 185);
+        DrINumber(temp, 45 - sboffset, 185);
     }
     if (!inventory)
     {
         if (CPlayer->readyArtifact > 0)
         {
             patch = DEH_String(patcharti[CPlayer->readyArtifact]);
-            V_DrawAltTLPatch(286, 170, W_CacheLumpName(DEH_String("ARTIBOX"), PU_CACHE));
-            V_DrawPatch(286, 170, W_CacheLumpName(patch, PU_CACHE));
-            DrSmallNumber(CPlayer->inventory[inv_ptr].count, 307, 192);
+            V_DrawAltTLPatch(286 + sboffset, 170, W_CacheLumpName(DEH_String("ARTIBOX"), PU_CACHE));
+            V_DrawPatch(286 + sboffset, 170, W_CacheLumpName(patch, PU_CACHE));
+            DrSmallNumber(CPlayer->inventory[inv_ptr].count, 307 + sboffset, 192);
         }
     }
     else
@@ -1750,3 +1939,51 @@ static void CheatNoTargetFunc(player_t *player, Cheat_t *cheat)
         P_SetMessage(player, DEH_String(TXT_CHEATNOTARGETOFF), false);
     }
 }
+
+// [crispy] crosshair color selection
+static byte *R_CrosshairColor (void)
+{
+    if (crispy->crosshaircolor == CROSSHAIRCOLOR_HE_GOLD)
+    {
+        return cr[CR_GOLD];
+    }
+    else if (crispy->crosshaircolor == CROSSHAIRCOLOR_HE_WHITE)
+    {
+        return cr[CR_GRAY];
+    }
+    else
+    {
+        return cr[CR_GREEN];
+    }
+}
+
+// [crispy] static, non-projected crosshair
+static void HU_DrawCrosshair (void)
+{
+    static int		lump;
+    static patch_t*	patch;
+    CPlayer = &players[consoleplayer];
+
+    if (wpnlev1info[CPlayer->readyweapon].ammo == am_noammo ||
+        wpnlev2info[CPlayer->readyweapon].ammo == am_noammo ||
+        CPlayer->playerstate != PST_LIVE ||
+        (automapactive && !crispy->automapoverlay) ||
+        MenuActive ||
+        paused)
+	    return;
+
+    if (lump != crosshairpatch[crispy->crosshairtype].l)
+    {
+        lump = crosshairpatch[crispy->crosshairtype].l;
+        patch = W_CacheLumpNum(lump, PU_STATIC);
+    }
+   
+    // crosshair color
+    dp_translation = R_CrosshairColor();
+    V_DrawSBPatch(ORIGWIDTH / 2 -
+            crosshairpatch[crispy->crosshairtype].w + crosshairpatch[crispy->crosshairtype].loffset,
+            ((screenblocks < 11) ? (ORIGHEIGHT - (SBARHEIGHT >> crispy->hires)) / 2 : ORIGHEIGHT / 2) -
+            crosshairpatch[crispy->crosshairtype].h + crosshairpatch[crispy->crosshairtype].toffset,
+            patch);
+    dp_translation = NULL;
+}
