@@ -1338,4 +1338,6 @@ void A_TreeDeath(mobj_t *actor, player_t *player, pspdef_t *psp)
 void A_NoGravity(mobj_t *actor, player_t *player, pspdef_t *psp)
 {
     actor->flags |= MF_NOGRAVITY;
+    if (actor->type == MT_THROWINGBOMB)
+        actor->flags |= MF_TRANSLUCENT; // [crispy] make exploding throwingbombs translucent
 }
