@@ -67,7 +67,7 @@
 #define SECRETWALLRANGE WALLRANGE
 #define GRIDCOLORS	(GRAYS + GRAYSRANGE/2)
 #define GRIDRANGE	0
-#define XHAIRCOLORS	GRAYS
+#define XHAIRCOLORS	WHITE
 
 // drawing stuff
 
