@@ -361,6 +361,14 @@ void G_BuildTiccmd(ticcmd_t *cmd, int maketic)
         lspeed = 2;             // 5;
     }
 
+    // [crispy] add quick 180° reverse
+    if (gamekeydown[key_reverse] || mousebuttons[mousebreverse])
+    {
+        angle += ANG180 >> FRACBITS;
+        gamekeydown[key_reverse] = false;
+        mousebuttons[mousebreverse] = false;
+    }
+
     // [crispy] toggle "always run"
     if (gamekeydown[key_toggleautorun])
     {
@@ -2094,7 +2102,8 @@ void G_LoadGame(int slot)
 void G_DoLoadGame(void)
 {
     gameaction = ga_nothing;
-    SV_LoadGame(GameLoadSlot);
+    // [crispy] support multiple pages of saves
+    SV_LoadGame(GameLoadSlot + savepage * 10);
     if (!netgame)
     {                           // Copy the base slot to the reborn slot
         SV_UpdateRebornSlot();
@@ -2127,7 +2136,8 @@ void G_SaveGame(int slot, char *description)
 
 void G_DoSaveGame(void)
 {
-    SV_SaveGame(savegameslot, savedescription);
+    // [crispy] support multiple pages of saves
+    SV_SaveGame(savegameslot + savepage * 10, savedescription);
     gameaction = ga_nothing;
     savedescription[0] = 0;
     P_SetMessage(&players[consoleplayer], TXT_GAMESAVED, true);
