@@ -76,6 +76,7 @@ typedef enum
     MENU_MOUSE,
     MENU_CRISPNESS1,
     MENU_CRISPNESS2,
+    MENU_CRISPNESS3,
     MENU_NONE
 } MenuType_t;
 
@@ -107,6 +108,7 @@ typedef struct
 } multiitem_t;
 
 // EXTERNAL FUNCTION PROTOTYPES --------------------------------------------
+extern void R_InitLightTables(void); // [crispy]
 extern void I_ReInitGraphics(int reinit); // [crispy]
 extern void R_ExecuteSetViewSize(void); // [crispy]
 extern void AM_LevelInit(boolean reinit); // [crispy]
@@ -136,7 +138,9 @@ static void CrispyUncapped(int option);
 static void CrispyFpsLimit(int option);
 static void CrispyVsync(int option);
 static void CrispyBrightmaps(int option);
+static void CrispySmoothLighting(int option);
 static void CrispySoundMono(int option);
+static void CrispyTranslucency(int option);
 static void CrispySndChannels(int option);
 static void CrispyPlayerCoords(int options);
 static void CrispyFreelook(int option);
@@ -144,6 +148,9 @@ static void CrispyMouselook(int option);
 static void CrispyBobfactor(int option);
 static void CrispyCenterWeapon(int option);
 static void CrispyDefaultskill(int option);
+static void CrispyCrosshair(int option);
+static void CrispyCrosshairShape(int option);
+static void CrispyCrosshairColor(int option);
 static void CrispyNextPage(int option);
 static void CrispyPrevPage(int option);
 static void SCNetCheck2(int option);
@@ -167,6 +174,7 @@ static void DrawMouseMenu(void);
 static void DrawCrispnessMenu(void);
 static void DrawCrispness1(void);
 static void DrawCrispness2(void);
+static void DrawCrispness3(void);
 void MN_LoadSlotText(void);
 
 // EXTERNAL DATA DECLARATIONS ----------------------------------------------
@@ -179,6 +187,8 @@ int InfoType;
 int messageson = true;
 boolean mn_SuicideConsole;
 
+int savepage; // [crispy] support 8 pages of savegames
+
 // PRIVATE DATA DEFINITIONS ------------------------------------------------
 
 static int FontABaseLump;
@@ -356,7 +366,7 @@ static Menu_t Options2Menu = {
 
 static int crispnessmenupage;
 
-#define NUM_CRISPNESS_MENUS 2
+#define NUM_CRISPNESS_MENUS 3
 
 static MenuItem_t Crispness1Items[] = {
     {ITT_LRFUNC2, "HIGH RESOLUTION RENDERING:", CrispyHires, 0, MENU_NONE},
@@ -368,12 +378,12 @@ static MenuItem_t Crispness1Items[] = {
     {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
     {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
     {ITT_LRFUNC2, "BRIGHTMAPS:", CrispyBrightmaps, 0, MENU_NONE},
+    {ITT_LRFUNC2, "SMOOTH DIMINISHING LIGHTING:", CrispySmoothLighting, 0, MENU_NONE},
+    {ITT_LRFUNC2, "ENABLE TRANSLUCENCY:", CrispyTranslucency, 0, MENU_NONE},
     {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
     {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
-    {ITT_LRFUNC2, "MONO SFX:", CrispySoundMono, 0, MENU_NONE},
-    {ITT_LRFUNC2, "SOUND CHANNELS:", CrispySndChannels, 0, MENU_NONE},
-    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
     {ITT_EFUNC, "NEXT PAGE", CrispyNextPage, 0, MENU_NONE},
+    {ITT_EFUNC, "LAST PAGE", CrispyPrevPage, 0, MENU_NONE},
 };
 
 static Menu_t Crispness1Menu = {
@@ -385,6 +395,10 @@ static Menu_t Crispness1Menu = {
 };
 
 static MenuItem_t Crispness2Items[] = {
+    {ITT_LRFUNC2, "MONO SFX:", CrispySoundMono, 0, MENU_NONE},
+    {ITT_LRFUNC2, "SOUND CHANNELS:", CrispySndChannels, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},   
     {ITT_LRFUNC2, "SHOW PLAYER COORDS:", CrispyPlayerCoords, 0, MENU_NONE},
     {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
     {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
@@ -394,13 +408,40 @@ static MenuItem_t Crispness2Items[] = {
     {ITT_LRFUNC2, "WEAPON ATTACK ALIGNMENT:", CrispyCenterWeapon, 0, MENU_NONE},
     {ITT_LRFUNC2, "DEFAULT DIFFICULTY:", CrispyDefaultskill, 0, MENU_NONE},
     {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_EFUNC, "NEXT PAGE", CrispyNextPage, 0, MENU_NONE},
     {ITT_EFUNC, "PREV PAGE", CrispyPrevPage, 0, MENU_NONE},
 };
 
 static Menu_t Crispness2Menu = {
     68, 35,
     DrawCrispnessMenu,
-    10, Crispness2Items,
+    15, Crispness2Items,
+    0,
+    MENU_OPTIONS
+};
+
+static MenuItem_t Crispness3Items[] = {
+    {ITT_LRFUNC2, "DRAW CROSSHAIR:", CrispyCrosshair, 0, MENU_NONE},
+    {ITT_LRFUNC2, "CROSSHAIR SHAPE:", CrispyCrosshairShape, 0, MENU_NONE},
+    {ITT_LRFUNC2, "CROSSHAIR COLOR:", CrispyCrosshairColor, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},   
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_EMPTY, NULL, NULL, 0, MENU_NONE},
+    {ITT_EFUNC, "FIRST PAGE", CrispyNextPage, 0, MENU_NONE},
+    {ITT_EFUNC, "PREV PAGE", CrispyPrevPage, 0, MENU_NONE},
+};
+
+static Menu_t Crispness3Menu = {
+    68, 35,
+    DrawCrispnessMenu,
+    15, Crispness3Items,
     0,
     MENU_OPTIONS
 };
@@ -408,11 +449,13 @@ static Menu_t Crispness2Menu = {
 static void (*CrispnessMenuDrawers[])(void) = {
     &DrawCrispness1,
     &DrawCrispness2,
+    &DrawCrispness3,
 };
 
 static MenuType_t CrispnessMenus[] = {
     MENU_CRISPNESS1,
     MENU_CRISPNESS2,
+    MENU_CRISPNESS3,
 };
 
 static const multiitem_t multiitem_bobfactor[NUM_BOBFACTORS] =
@@ -469,6 +512,41 @@ static const multiitem_t multiitem_difficulties[NUM_SKILLS] =
     {SKILL_HNTR, "EASY"},
 };
 
+multiitem_t multiitem_he_crosshair[NUM_HE_CROSSHAIRS] =
+{
+    {CROSSHAIR_HE_OFF, "off"},
+    {CROSSHAIR_HE_OPAQUE, "opaque"},
+    {CROSSHAIR_HE_TRANSLUCENT, "translucent"},
+};
+
+multiitem_t multiitem_he_crosshairtype[] =
+{
+    {-1, "none"},
+    {CROSSHAIRTYPE_HE_DOT, "dot"},
+    {CROSSHAIRTYPE_HE_CROSS1, "cross1"},
+    {CROSSHAIRTYPE_HE_CROSS2, "cross2"},
+};
+
+// [crispy] crosshair colors for hexen
+// gold: corresponding with normal hud / crispy hud font
+// white: corresponding with hud messages / providing high visibility
+// red: corresponding with vanilla fullscreen hud font
+multiitem_t multiitem_he_crosshaircolor[] =
+{
+    {-1, "none"},
+    {CROSSHAIRCOLOR_HE_GOLD, "gold"},
+    {CROSSHAIRCOLOR_HE_WHITE, "white"},
+    {CROSSHAIRCOLOR_HE_FSHUD, "red"},
+};
+
+multiitem_t multiitem_translucency[NUM_TRANSLUCENCY] =
+{
+    {TRANSLUCENCY_OFF, "OFF"},
+    {TRANSLUCENCY_MISSILE, "PROJECTILES"},
+    {TRANSLUCENCY_ITEM, "WEAPON FLASHES"},
+    {TRANSLUCENCY_BOTH, "BOTH"},
+};
+
 static const multiitem_t multiitem_sndchannels[3] =
 {
     {8, "8"},
@@ -488,6 +566,7 @@ static Menu_t *Menus[] = {
     &MouseMenu,
     &Crispness1Menu,
     &Crispness2Menu,
+    &Crispness3Menu,
 };
 
 // [crispy] intermediate gamma levels
@@ -594,7 +673,7 @@ void MN_DrTextA(const char *text, int x, int y)
         else
         {
             p = W_CacheLumpNum(FontABaseLump + c - 33, PU_CACHE);
-            V_DrawPatch(x, y, p);
+            V_DrawSBPatch(x, y, p);
             x += SHORT(p->width) - 1;
         }
     }
@@ -622,7 +701,7 @@ void MN_DrTextAYellow(const char *text, int x, int y)
         else
         {
             p = W_CacheLumpNum(FontAYellowBaseLump + c - 33, PU_CACHE);
-            V_DrawPatch(x, y, p);
+            V_DrawSBPatch(x, y, p);
             x += SHORT(p->width) - 1;
         }
     }
@@ -841,7 +920,7 @@ void MN_Drawer(void)
             y = CurrentMenu->y + (CurrentItPos * ITEM_HEIGHT/2) + SELECTOR_YOFFSET;
             selName = MenuTime & 8 ? "INVGEMR1" : "INVGEMR2";
             V_DrawPatch(x + (SELECTOR_XOFFSET/2), y,
-                        W_CacheLumpName(selName, PU_CACHE));
+                        W_CacheLumpName(selName, PU_STATIC));
         }
         else
         {
@@ -953,7 +1032,8 @@ static void DrawSaveLoadBottomLine(const Menu_t *menu)
         char filename[100];
 
         M_snprintf(filename, sizeof(filename), "%shex%d.hxs", SavePath, CurrentItPos + (savepage * 10));
-        stat(filename, &st);
+        if (M_stat(filename, &st) == 0)
+        {
 // [FG] suppress the most useless compiler warning ever
 #if defined(__GNUC__)
 #  pragma GCC diagnostic push
@@ -964,6 +1044,7 @@ static void DrawSaveLoadBottomLine(const Menu_t *menu)
 #  pragma GCC diagnostic pop
 #endif
         MN_DrTextA(filedate, ORIGWIDTH / 2 - MN_TextAWidth(filedate) / 2, y + 10);
+        }
     }
 
     dp_translation = NULL;
@@ -1113,7 +1194,7 @@ static void DrawOptionsMenu(void)
 
 static void DrawOptions2Menu(void)
 {
-    DrawSlider(&Options2Menu, 1, 9, screenblocks - 3);
+    DrawSlider(&Options2Menu, 1, 14, screenblocks - 3);
     DrawSlider(&Options2Menu, 3, 16, snd_MaxVolume);
     DrawSlider(&Options2Menu, 5, 16, snd_MusicVolume);
 }
@@ -1258,7 +1339,7 @@ static void SCDeleteGame(int option)
         return;
     }
 
-    SV_ClearSaveSlot(option);
+    SV_ClearSaveSlot(option + savepage * 10);
     CurrentMenu->oldItPos = CurrentItPos;
     MN_LoadSlotText();
     BorderNeedRefresh = true;
@@ -1562,7 +1643,7 @@ static void SCScreenSize(int option)
 {
     if (option == RIGHT_DIR)
     {
-        if (screenblocks < 11)
+        if (screenblocks < 16)
         {
             screenblocks++;
         }
@@ -1571,7 +1652,7 @@ static void SCScreenSize(int option)
     {
         screenblocks--;
     }
-    R_SetViewSize(screenblocks, detailLevel);
+    R_SetViewSize(BETWEEN(3, 11, screenblocks), detailLevel);
 }
 
 //---------------------------------------------------------------------------
@@ -1655,7 +1736,7 @@ static void CrispyToggleWidescreen(int option)
 
 static void CrispySmoothing(int option)
 {
-    crispy->smoothscaling = !crispy->smoothscaling;
+    smooth_pixel_scaling = !smooth_pixel_scaling;
 }
 
 static void CrispyUncapped(int option)
@@ -1727,11 +1808,34 @@ static void CrispyBrightmaps(int option)
     ChangeSettingEnum(&crispy->brightmaps, option, NUM_BRIGHTMAPS);
 }
 
+static void CrispySmoothLightingHook (void)
+{
+    crispy->smoothlight = !crispy->smoothlight;
+#ifdef CRISPY_TRUECOLOR
+    // [crispy] re-calculate amount of colormaps and light tables
+    R_InitTrueColormaps(LevelUseFullBright ? "COLORMAP" : "FOGMAP");
+#endif
+    // [crispy] re-calculate the zlight[][] array
+    R_InitLightTables();
+    // [crispy] re-calculate the scalelight[][] array
+    R_ExecuteSetViewSize();
+}
+
+static void CrispySmoothLighting(int option)
+{
+    crispy->post_rendering_hook = CrispySmoothLightingHook;
+}
+
 static void CrispySoundMono(int option)
 {
     crispy->soundmono = !crispy->soundmono;
 }
 
+static void CrispyTranslucency(int choice)
+{
+    ChangeSettingEnum(&crispy->translucency, choice, NUM_TRANSLUCENCY);
+}
+
 static void CrispySndChannels(int option)
 {
     S_UpdateSndChannels(option);
@@ -1774,6 +1878,31 @@ static void CrispyDefaultskill(int option)
     SkillMenu.oldItPos = (crispy->defaultskill + SKILL_HMP) % NUM_SKILLS;
 }
 
+static void CrispyCrosshair(int option)
+{
+    ChangeSettingEnum(&crispy->crosshair, option, NUM_HE_CROSSHAIRS);
+}
+
+static void CrispyCrosshairShape(int option)
+{
+    if (!crispy->crosshair)
+    {
+	    return;
+    }
+
+    ChangeSettingEnum(&crispy->crosshairtype, option, NUM_HE_CROSSHAIRTYPE);
+}
+
+static void CrispyCrosshairColor(int option)
+{
+    if (!crispy->crosshair)
+    {
+	    return;
+    }
+
+    ChangeSettingEnum(&crispy->crosshaircolor, option, NUM_HE_CROSSHAIRCOLOR);
+}
+
 static void CrispyNextPage(int option)
 {
     crispnessmenupage++;
@@ -2943,7 +3072,7 @@ static void DrawCrispnessNumericItem(int item, int x, int y, const char *zero,
 
 static void DrawCrispness1(void)
 {
-    DrawCrispnessHeader("CRISPNESS 1/2");
+    DrawCrispnessHeader("CRISPNESS 1/3");
 
     DrawCrispnessSubheader("RENDERING", 25);
 
@@ -2954,7 +3083,7 @@ static void DrawCrispness1(void)
     DrawCrispnessMultiItem(crispy->widescreen, 164, 45, multiitem_widescreen, false);
 
     // Smooth pixel scaling
-    DrawCrispnessItem(crispy->smoothscaling, 216, 55);
+    DrawCrispnessItem(smooth_pixel_scaling, 216, 55);
 
     // Uncapped framerate
     DrawCrispnessItem(crispy->uncapped, 217, 65);
@@ -2970,39 +3099,61 @@ static void DrawCrispness1(void)
     // Brightmaps
     DrawCrispnessMultiItem(crispy->brightmaps, 150, 115, multiitem_brightmaps, false);
 
-    DrawCrispnessSubheader("AUDIBLE", 135);
+    // Smooth Diminishing Lighting
+    DrawCrispnessItem(crispy->smoothlight, 257, 125);
 
-    // Mono SFX
-    DrawCrispnessItem(crispy->soundmono, 137, 145);
-
-    // Sound Channels
-    DrawCrispnessMultiItem(snd_Channels >> 4, 181, 155, multiitem_sndchannels, false);
+    // Translucency
+    DrawCrispnessMultiItem(crispy->translucency, 218, 135, multiitem_translucency, false);
 }
 
 static void DrawCrispness2(void)
 {
-    DrawCrispnessHeader("CRISPNESS 2/2");
+    DrawCrispnessHeader("CRISPNESS 2/3");
 
-    DrawCrispnessSubheader("NAVIGATIONAL", 25);
+    DrawCrispnessSubheader("AUDIBLE", 25);
+
+    // Mono SFX
+    DrawCrispnessItem(crispy->soundmono, 137, 35);
+
+    // Sound Channels
+    DrawCrispnessMultiItem(snd_Channels >> 4, 181, 45, multiitem_sndchannels, false);
+
+    DrawCrispnessSubheader("NAVIGATIONAL", 65);
 
     // Player coordinates
-    DrawCrispnessMultiItem(crispy->playercoords, 211, 35, multiitem_widgets, false);
+    DrawCrispnessMultiItem(crispy->playercoords, 211, 75, multiitem_widgets, false);
 
-    DrawCrispnessSubheader("TACTICAL", 55);
+    DrawCrispnessSubheader("TACTICAL", 95);
 
     // Freelook
-    DrawCrispnessMultiItem(crispy->freelook_hh, 175, 65, multiitem_freelook_hh, false);
+    DrawCrispnessMultiItem(crispy->freelook_hh, 175, 105, multiitem_freelook_hh, false);
 
     // Mouselook
-    DrawCrispnessItem(crispy->mouselook, 220, 75);
+    DrawCrispnessItem(crispy->mouselook, 220, 115);
 
     // Bobfactor
-    DrawCrispnessMultiItem(crispy->bobfactor, 265, 85, multiitem_bobfactor, false);
+    DrawCrispnessMultiItem(crispy->bobfactor, 265, 125, multiitem_bobfactor, false);
 
     // Weapon attack alignment
-    DrawCrispnessMultiItem(crispy->centerweapon, 245, 95, multiitem_centerweapon,
+    DrawCrispnessMultiItem(crispy->centerweapon, 245, 135, multiitem_centerweapon,
             crispy->bobfactor == BOBFACTOR_OFF);
 
     // Default difficulty
-    DrawCrispnessMultiItem(crispy->defaultskill, 200, 105, multiitem_difficulties, false);
+    DrawCrispnessMultiItem(crispy->defaultskill, 200, 145, multiitem_difficulties, false);
+}
+
+static void DrawCrispness3(void)
+{
+    DrawCrispnessHeader("CRISPNESS 3/3");
+
+    DrawCrispnessSubheader("CROSSHAIR", 25);
+
+    // Crosshair
+    DrawCrispnessMultiItem(crispy->crosshair, 180, 35, multiitem_he_crosshair, false);
+
+    // Crosshair Type
+    DrawCrispnessMultiItem(crispy->crosshairtype+1, 188, 45, multiitem_he_crosshairtype, !crispy->crosshair);
+
+    // Crosshair Color
+    DrawCrispnessMultiItem(crispy->crosshaircolor+1, 185, 55, multiitem_he_crosshaircolor, !crispy->crosshair);
 }
