@@ -18,6 +18,7 @@
 #include "h2def.h"
 #include "i_system.h"
 #include "m_bbox.h"
+#include "m_misc.h"
 #include "p_local.h"
 
 static mobj_t *RoughBlockCheck(mobj_t * mo, int index);
@@ -431,7 +432,6 @@ boolean P_BlockLinesIterator(int x, int y, boolean(*func) (line_t *))
     int i;
     polyblock_t *polyLink;
     seg_t **tempSeg;
-    extern polyblock_t **PolyBlockMap;
 
     if (x < 0 || y < 0 || x >= bmapwidth || y >= bmapheight)
         return true;
@@ -495,6 +495,8 @@ boolean P_BlockThingsIterator(int x, int y, boolean(*func) (mobj_t *))
     if (x < 0 || y < 0 || x >= bmapwidth || y >= bmapheight)
         return true;
 
+    LINKED_LIST_CHECK_NO_CYCLE(mobj_t, blocklinks[y*bmapwidth+x], bnext);
+
     for (mobj = blocklinks[y * bmapwidth + x]; mobj; mobj = mobj->bnext)
         if (!func(mobj))
             return false;
