@@ -21,6 +21,7 @@
 #include "m_random.h"
 #include "p_local.h"
 #include "s_sound.h"
+#include "a11y.h" // [crispy] A11Y
 
 // MACROS ------------------------------------------------------------------
 
@@ -1187,13 +1188,17 @@ void A_MStaffAttack(mobj_t *actor, player_t *player, pspdef_t *psp)
     {
         player->damagecount = 0;
         player->bonuscount = 0;
+        // [crispy] A11Y
+        if(a11y_weapon_palette)
+        {
 #ifndef CRISPY_TRUECOLOR
-        I_SetPalette((byte *) W_CacheLumpNum(W_GetNumForName("playpal"),
+            I_SetPalette((byte *) W_CacheLumpNum(W_GetNumForName("playpal"),
                                              PU_CACHE) +
-                     STARTSCOURGEPAL * 768);
+                        STARTSCOURGEPAL * 768);
 #else
-        I_SetPalette(STARTSCOURGEPAL);
-#endif
+            I_SetPalette(STARTSCOURGEPAL);
+#endif            
+        }
     }
 }
 
@@ -1207,7 +1212,8 @@ void A_MStaffPalette(mobj_t *actor, player_t *player, pspdef_t *psp)
 {
     int pal;
 
-    if (player == &players[consoleplayer])
+    // [crispy] A11Y
+    if (a11y_weapon_palette && player == &players[consoleplayer]) 
     {
         pal = STARTSCOURGEPAL + psp->state - (&states[S_MSTAFFATK_2]);
         if (pal == STARTSCOURGEPAL + 3)
@@ -1937,12 +1943,16 @@ void A_CHolyAttack(mobj_t *actor, player_t *player, pspdef_t *psp)
     {
         player->damagecount = 0;
         player->bonuscount = 0;
+        // [crispy] A11Y
+        if(a11y_weapon_palette)
+        {
 #ifndef CRISPY_TRUECOLOR
-        I_SetPalette((byte *) W_CacheLumpNum(W_GetNumForName("playpal"),
-                                             PU_CACHE) + STARTHOLYPAL * 768);
+            I_SetPalette((byte *) W_CacheLumpNum(W_GetNumForName("playpal"),
+                                                PU_CACHE) + STARTHOLYPAL * 768);
 #else
-        I_SetPalette(STARTHOLYPAL);
+            I_SetPalette(STARTHOLYPAL);
 #endif
+        }
     }
     S_StartSound(player->mo, SFX_CHOLY_FIRE);
 }
@@ -1957,7 +1967,8 @@ void A_CHolyPalette(mobj_t *actor, player_t *player, pspdef_t *psp)
 {
     int pal;
 
-    if (player == &players[consoleplayer])
+    // [crispy] A11Y
+    if (a11y_weapon_palette && player == &players[consoleplayer])
     {
         pal = STARTHOLYPAL + psp->state - (&states[S_CHOLYATK_6]);
         if (pal == STARTHOLYPAL + 3)
