@@ -53,6 +53,7 @@ int firstspritelump, lastspritelump, numspritelumps;
 int numtextures;
 texture_t **textures;
 int *texturewidthmask;
+int *texturewidth; // [crispy] texture width for wrapping column getter function
 fixed_t *textureheight;         // needed for texture pegging
 int *texturecompositesize;
 short **texturecolumnlump;
@@ -525,6 +526,7 @@ void R_InitTextures(void)
     texturecomposite = Z_Malloc(numtextures * sizeof(byte *), PU_STATIC, 0);
     texturecompositesize = Z_Malloc(numtextures * sizeof(int), PU_STATIC, 0);
     texturewidthmask = Z_Malloc(numtextures * sizeof(int), PU_STATIC, 0);
+    texturewidth = Z_Malloc (numtextures * sizeof(*texturewidth), PU_STATIC, 0);
     textureheight = Z_Malloc(numtextures * sizeof(fixed_t), PU_STATIC, 0);
     texturebrightmap = Z_Malloc (numtextures * sizeof(*texturebrightmap), PU_STATIC, 0);
 
@@ -571,6 +573,9 @@ void R_InitTextures(void)
             j <<= 1;
         texturewidthmask[i] = j - 1;
         textureheight[i] = texture->height << FRACBITS;
+
+        // [crispy] texture width for wrapping column getter function
+        texturewidth[i] = texture->width;
     }
 
     Z_Free(patchlookup);
@@ -675,6 +680,7 @@ void R_InitColormaps(void)
     length = W_LumpLength(lump);
     colormaps = Z_Malloc(length, PU_STATIC, 0);
     W_ReadLump(lump, colormaps);
+    NUMCOLORMAPS = 32; // [crispy] smooth diminishing lighting
 }
 
 #else
@@ -688,10 +694,19 @@ void R_InitTrueColormaps(char *current_colormap)
 	byte *const playpal = W_CacheLumpName("PLAYPAL", PU_STATIC);
 	byte *const colormap = W_CacheLumpName(current_colormap, PU_STATIC);
 
-	if (!colormaps)
+	// [crispy] Smoothest diminishing lighting.
+	// Compiled in but not enabled TrueColor mode
+	// can't use more than original 32 colormaps.
+	if (crispy->truecolor && crispy->smoothlight)
 	{
-		colormaps = (lighttable_t*) Z_Malloc((NUMCOLORMAPS + 1) * 256 * sizeof(lighttable_t), PU_STATIC, 0);
+		NUMCOLORMAPS = 256;
 	}
+	else
+	{
+		NUMCOLORMAPS = 32;
+	}
+
+	colormaps = I_Realloc(colormaps, (NUMCOLORMAPS + 1) * 256 * sizeof(lighttable_t));
 
 	if (crispy->truecolor)
 	{
@@ -805,6 +820,15 @@ void R_InitData(void)
 
 //=============================================================================
 
+// [crispy] Used to grab actual height of sky textures
+int R_GetPatchHeight(int texture_num, int patch_index)
+{
+    texpatch_t *texpatch = &textures[texture_num]->patches[patch_index];
+    patch_t *patch = W_CacheLumpNum(texpatch->patch, PU_CACHE);
+
+    return  SHORT(patch->height);
+}
+
 /*
 ================
 =
