@@ -23,6 +23,7 @@
 #include "r_bmaps.h"
 #include "r_local.h"
 #include "v_trans.h" // [crispy] blending functions
+#include "a11y.h" // [crispy] A11Y
 
 //void R_DrawTranslatedAltTLColumn(void);
 
@@ -61,6 +62,12 @@ boolean LevelUseFullBright;
 ===============================================================================
 */
 
+// [crispy] check if player sprite base frame has to be drawn
+static int R_CheckPSpriteDrawbase(pspdef_t * psp);
+
+// [crispy] check if player sprite is translucent due to active power
+static boolean R_CheckPowerBasedTranslucency(void);
+
 // variables used to look up and range check thing_t sprites patches
 spritedef_t *sprites;
 int numsprites;
@@ -428,6 +435,18 @@ void R_DrawVisSprite(vissprite_t * vis, int x1, int x2)
             + vis->class * ((maxplayers - 1) * 256) +
             ((vis->mobjflags & MF_TRANSLATION) >> (MF_TRANSSHIFT - 8));
     }
+    // [crispy] translucent sprites
+    else if (crispy->translucency && vis->mobjflags & MF_TRANSLUCENT)
+    {
+    	if ((crispy->translucency & TRANSLUCENCY_MISSILE) ||
+            (vis->psprite && crispy->translucency & TRANSLUCENCY_ITEM))
+            {
+	            colfunc = tlcolfunc;
+            }
+#ifdef CRISPY_TRUECOLOR
+            blendfunc = vis->blendfunc;
+#endif
+    }
 
     dc_iscale = abs(vis->xiscale) >> detailshift;
     dc_texturemid = vis->texturemid;
@@ -670,7 +689,7 @@ void R_ProjectSprite(mobj_t * thing)
 #ifdef CRISPY_TRUECOLOR
     // [crispy] not using additive blending (I_BlendAdd) here for full
     // bright states to preserve look & feel of original Hexen's translucency
-    if (thing->flags & MF_SHADOW)
+    if (thing->flags & MF_SHADOW || thing->flags & MF_TRANSLUCENT)
     {
         vis->blendfunc = I_BlendOverTinttab;
     }
@@ -703,7 +722,7 @@ void R_AddSprites(sector_t * sec)
 
     sec->validcount = validcount;
 
-    lightnum = (sec->lightlevel >> LIGHTSEGSHIFT) + extralight;
+    lightnum = (sec->rlightlevel >> LIGHTSEGSHIFT) + (extralight * LIGHTBRIGHT); // [crispy] smooth diminishing lighting, A11Y
     if (lightnum < 0)
         spritelights = scalelight[0];
     else if (lightnum >= LIGHTLEVELS)
@@ -735,7 +754,7 @@ int PSpriteSY[NUMCLASSES][NUMWEAPONS] = {
 
 boolean pspr_interp = true; // [crispy] interpolate weapon bobbing
 
-void R_DrawPSprite(pspdef_t * psp)
+void R_DrawPSprite(pspdef_t * psp, int translucent) // [crispy] translucency for weapon flash translucency
 {
     fixed_t tx;
     int x1, x2;
@@ -869,6 +888,15 @@ void R_DrawPSprite(pspdef_t * psp)
     }
     vis->brightmap = R_BrightmapForState(psp->state - states);
 
+    // [crispy] translucent weapon flash sprites
+    if (translucent)
+    {
+        vis->mobjflags |= MF_TRANSLUCENT;
+#ifdef CRISPY_TRUECOLOR
+        vis->blendfunc = I_BlendOverTinttab;
+#endif        
+    }
+
     // [crispy] interpolate weapon bobbing
     if (crispy->uncapped)
     {
@@ -918,14 +946,15 @@ void R_DrawPSprite(pspdef_t * psp)
 void R_DrawPlayerSprites(void)
 {
     int i, lightnum;
+    int tmpframe, drawbase = 0; // [crispy] for drawing base frames
     pspdef_t *psp;
 
 //
 // get light level
 //
     lightnum =
-        (viewplayer->mo->subsector->sector->lightlevel >> LIGHTSEGSHIFT) +
-        extralight;
+        (viewplayer->mo->subsector->sector->rlightlevel >> LIGHTSEGSHIFT) +  // [crispy] A11Y
+        (extralight * LIGHTBRIGHT); // [crispy] smooth diminishing lighting
     if (lightnum < 0)
         spritelights = scalelight[0];
     else if (lightnum >= LIGHTLEVELS)
@@ -942,11 +971,87 @@ void R_DrawPlayerSprites(void)
 // add all active psprites
 //
     for (i = 0, psp = viewplayer->psprites; i < NUMPSPRITES; i++, psp++)
+    {
         if (psp->state)
-            R_DrawPSprite(psp);
-
+        {
+            // [crispy] draw base frame for transparent or deactivated weapon flashes
+            if (!a11y_weapon_pspr || 
+                (crispy->translucency & TRANSLUCENCY_ITEM && !R_CheckPowerBasedTranslucency()))
+            {
+                tmpframe = psp->state->frame;
+                drawbase = R_CheckPSpriteDrawbase(psp);
+                if (drawbase)
+                {
+                    psp->state->frame = 0; // set base frame
+                    R_DrawPSprite(psp, 0);
+                    psp->state->frame = tmpframe; // restore attack frame
+                }
+            }
+            if (!a11y_weapon_pspr && drawbase) 
+                continue; // [crispy] A11Y no weapon flash, use base instead
+            R_DrawPSprite(psp, drawbase); // [crispy] translucent when base was drawn
+        }      
+    }
 }
 
+/*
+========================
+=
+= [crispy] R_CheckPSpriteDrawbase
+=
+= Check if player sprite base frame has to be drawn
+========================
+*/
+
+static int R_CheckPSpriteDrawbase(pspdef_t * psp)
+{
+    int drawbase = 0;
+    int frame = psp->state->frame;
+
+    switch (psp->state->sprite)
+    {         
+        case SPR_MWND:
+            if (frame == (1 | FF_FULLBRIGHT))
+                drawbase = 1;
+            break;
+        case SPR_MSTF:
+            if ((frame >= 6 && frame <= 9) ||
+                    frame == (7 | FF_FULLBRIGHT))
+                drawbase = 1;
+            break;
+        case SPR_CSSF:
+            if (frame == 9)
+                drawbase = 1;
+            break;
+        case SPR_CHLY:
+            if (frame >= (0 | FF_FULLBRIGHT) && frame <= (5 | FF_FULLBRIGHT))
+                drawbase = 1;
+            break;
+        default:
+            drawbase = 0;
+            break;
+    }
+    return drawbase;
+}
+
+/*
+========================
+=
+= [crispy] R_CheckPowerBasedTranslucency
+=
+= Check if player sprite is translucent due to active power
+========================
+*/
+
+static boolean R_CheckPowerBasedTranslucency(void)
+{
+    if (viewplayer->class == PCLASS_CLERIC && viewplayer->powers[pw_invulnerability] &&
+        ((viewplayer->powers[pw_invulnerability] > 4*32 || viewplayer->powers[pw_invulnerability] & 8) && 
+         viewplayer->mo->flags & MF_SHADOW))
+        return true;
+    else
+        return false;
+}
 
 /*
 ========================
