@@ -177,6 +177,11 @@ static boolean SDLIsInitialized(void)
     return Mix_QuerySpec(&freq, &format, &channels) != 0;
 }
 
+#ifdef _WIN32
+// putenv requires a non-const string whose lifetime is the whole program
+static char sdl_mixer_disable_nativemidi[] = "SDL_MIXER_DISABLE_NATIVEMIDI=1";
+#endif
+
 // Initialize music subsystem
 static boolean I_SDL_InitMusic(void)
 {
@@ -208,6 +213,12 @@ static boolean I_SDL_InitMusic(void)
         }
     }
 
+    #ifdef _WIN32
+    // Never let SDL Mixer use native midi on Windows. Avoids SDL Mixer bug
+    // where music volume affects global application volume.
+    putenv(sdl_mixer_disable_nativemidi);
+    #endif
+
     // Initialize SDL_Mixer for MIDI music playback
     Mix_Init(MIX_INIT_MID | MIX_INIT_FLAC | MIX_INIT_OGG | MIX_INIT_MP3); // [crispy] initialize some more audio formats
 
