@@ -87,8 +87,6 @@ static SDL_Rect blit_rect = {
 };
 #endif
 
-static uint32_t pixel_format;
-
 // palette
 
 #ifdef CRISPY_TRUECOLOR
@@ -102,7 +100,6 @@ static SDL_Texture *bluepane = NULL;
 static SDL_Texture *graypane = NULL;
 static SDL_Texture *orngpane = NULL;
 static int pane_alpha;
-static unsigned int rmask, gmask, bmask, amask; // [crispy] moved up here
 extern pixel_t* pal_color; // [crispy] evil hack to get FPS dots working as in Vanilla
 #else
 static SDL_Color palette[256];
@@ -156,6 +153,9 @@ int fullscreen = true;
 int aspect_ratio_correct = true;
 static int actualheight;
 
+// Smooth pixel scaling
+int smooth_pixel_scaling = true;
+
 // Force integer scales for resolution-independent rendering
 
 int integer_scaling = false;
@@ -300,6 +300,14 @@ void I_ShutdownGraphics(void)
     {
         SetShowCursor(true);
 
+        SDL_FreeSurface(argbbuffer);
+#ifndef CRISPY_TRUECOLOR
+        SDL_FreeSurface(screenbuffer);
+#endif
+        SDL_DestroyTexture(texture_upscaled);
+        SDL_DestroyTexture(texture);
+        SDL_DestroyRenderer(renderer);
+        SDL_DestroyWindow(screen);
         SDL_QuitSubSystem(SDL_INIT_VIDEO);
 
         initialized = false;
@@ -537,11 +545,14 @@ void I_StartTic (void)
     }
 }
 
-void I_StartDisplay(void) // [crispy]
+void I_UpdateFracTic(void) // [crispy]
 {
     // [AM] Figure out how far into the current tic we're in as a fixed_t.
     fractionaltic = I_GetFracRealTime();
+}
 
+void I_StartDisplay(void) // [crispy]
+{
     SDL_PumpEvents();
 
     if (usemouse && !nomouse && window_focused)
@@ -733,7 +744,7 @@ static void CreateUpscaledTexture(boolean force)
     SDL_SetHint(SDL_HINT_RENDER_SCALE_QUALITY, "linear");
 
     new_texture = SDL_CreateTexture(renderer,
-                                pixel_format,
+                                SDL_PIXELFORMAT_ARGB8888,
                                 SDL_TEXTUREACCESS_TARGET,
                                 w_upscale*SCREENWIDTH,
                                 h_upscale*SCREENHEIGHT);
@@ -866,36 +877,37 @@ void I_FinishUpdate (void)
     }
 
     // Blit from the paletted 8-bit screen buffer to the intermediate
-    // 32-bit RGBA buffer that we can load into the texture.
+    // 32-bit RGBA buffer and update the intermediate texture with the
+    // contents of the RGBA buffer.
 
+    SDL_LockTexture(texture, &blit_rect, &argbbuffer->pixels,
+                    &argbbuffer->pitch);
     SDL_LowerBlit(screenbuffer, &blit_rect, argbbuffer, &blit_rect);
-#endif
-
-    // Update the intermediate texture with the contents of the RGBA buffer.
-
+    SDL_UnlockTexture(texture);
+#else
     SDL_UpdateTexture(texture, NULL, argbbuffer->pixels, argbbuffer->pitch);
+#endif
 
     // Make sure the pillarboxes are kept clear each frame.
 
     SDL_RenderClear(renderer);
 
-    if (crispy->smoothscaling && !force_software_renderer)
+    if (smooth_pixel_scaling && !force_software_renderer)
     {
-    // Render this intermediate texture into the upscaled texture
-    // using "nearest" integer scaling.
+        // Render this intermediate texture into the upscaled texture
+        // using "nearest" integer scaling.
+        SDL_SetRenderTarget(renderer, texture_upscaled);
+        SDL_RenderCopy(renderer, texture, NULL, NULL);
 
-    SDL_SetRenderTarget(renderer, texture_upscaled);
-    SDL_RenderCopy(renderer, texture, NULL, NULL);
+        // Finally, render this upscaled texture to screen using linear scaling.
 
-    // Finally, render this upscaled texture to screen using linear scaling.
-
-    SDL_SetRenderTarget(renderer, NULL);
-    SDL_RenderCopy(renderer, texture_upscaled, NULL, NULL);
+        SDL_SetRenderTarget(renderer, NULL);
+        SDL_RenderCopy(renderer, texture_upscaled, NULL, NULL);
     }
     else
     {
-	SDL_SetRenderTarget(renderer, NULL);
-	SDL_RenderCopy(renderer, texture, NULL, NULL);
+        SDL_SetRenderTarget(renderer, NULL);
+        SDL_RenderCopy(renderer, texture, NULL, NULL);
     }
 
 #ifdef CRISPY_TRUECOLOR
@@ -1005,6 +1017,7 @@ void I_SetPalette (byte *doompalette)
         // controller only supports 6 bits of accuracy.
 
         // [crispy] intermediate gamma levels
+        palette[i].a = 0xFFU;
         palette[i].r = gamma2table[crispy->gamma][*doompalette++] & ~3;
         palette[i].g = gamma2table[crispy->gamma][*doompalette++] & ~3;
         palette[i].b = gamma2table[crispy->gamma][*doompalette++] & ~3;
@@ -1259,9 +1272,9 @@ void I_GraphicsCheckCommandLine(void)
 
     //!
     // @category video
-    // @arg <x>
+    // @arg <W>
     //
-    // Specify the screen width, in pixels. Implies -window.
+    // Specify the screen width, in pixels.  Implies -window.
     //
 
     i = M_CheckParmWithArgs("-width", 1);
@@ -1274,9 +1287,9 @@ void I_GraphicsCheckCommandLine(void)
 
     //!
     // @category video
-    // @arg <y>
+    // @arg <H>
     //
-    // Specify the screen height, in pixels. Implies -window.
+    // Specify the screen height, in pixels.  Implies -window.
     //
 
     i = M_CheckParmWithArgs("-height", 1);
@@ -1289,9 +1302,9 @@ void I_GraphicsCheckCommandLine(void)
 
     //!
     // @category video
-    // @arg <WxY>
+    // @arg <WxH>
     //
-    // Specify the dimensions of the window. Implies -window.
+    // Specify the dimensions of the window.  Implies -window.
     //
 
     i = M_CheckParmWithArgs("-geometry", 1);
@@ -1330,7 +1343,7 @@ void I_GraphicsCheckCommandLine(void)
     //!
     // @category video
     //
-    // Don't scale up the screen. Implies -window.
+    // Don't scale up the screen.  Implies -window.
     //
 
     if (M_CheckParm("-1")) 
@@ -1341,7 +1354,7 @@ void I_GraphicsCheckCommandLine(void)
     //!
     // @category video
     //
-    // Double up the screen to 2x its normal size. Implies -window.
+    // Double up the screen to 2x its normal size.  Implies -window.
     //
 
     if (M_CheckParm("-2")) 
@@ -1352,7 +1365,7 @@ void I_GraphicsCheckCommandLine(void)
     //!
     // @category video
     //
-    // Double up the screen to 3x its normal size. Implies -window.
+    // Double up the screen to 3x its normal size.  Implies -window.
     //
 
     if (M_CheckParm("-3")) 
@@ -1456,10 +1469,6 @@ static void SetVideoMode(void)
 {
     int w, h;
     int x, y;
-#ifndef CRISPY_TRUECOLOR
-    unsigned int rmask, gmask, bmask, amask;
-#endif
-    int bpp;
     int window_flags = 0, renderer_flags = 0;
     SDL_DisplayMode mode;
 
@@ -1517,8 +1526,6 @@ static void SetVideoMode(void)
             SDL_GetError());
         }
 
-        pixel_format = SDL_GetWindowPixelFormat(screen);
-
         SDL_SetWindowMinimumSize(screen, SCREENWIDTH, actualheight);
 
         I_InitWindowTitle();
@@ -1635,12 +1642,10 @@ static void SetVideoMode(void)
 
     if (argbbuffer == NULL)
     {
-        SDL_PixelFormatEnumToMasks(pixel_format, &bpp,
-                                   &rmask, &gmask, &bmask, &amask);
-        argbbuffer = SDL_CreateRGBSurface(0,
-                                          SCREENWIDTH, SCREENHEIGHT, bpp,
-                                          rmask, gmask, bmask, amask);
 #ifdef CRISPY_TRUECOLOR
+        argbbuffer = SDL_CreateRGBSurfaceWithFormat(
+                     0, SCREENWIDTH, SCREENHEIGHT, 32, SDL_PIXELFORMAT_ARGB8888);
+
         SDL_FillRect(argbbuffer, NULL, I_MapRGB(0xff, 0x0, 0x0));
         redpane = SDL_CreateTextureFromSurface(renderer, argbbuffer);
         SDL_SetTextureBlendMode(redpane, SDL_BLENDMODE_BLEND);
@@ -1668,8 +1673,12 @@ static void SetVideoMode(void)
         SDL_FillRect(argbbuffer, NULL, I_MapRGB(0x96, 0x6e, 0x0)); // 150, 110, 0
         orngpane = SDL_CreateTextureFromSurface(renderer, argbbuffer);
         SDL_SetTextureBlendMode(orngpane, SDL_BLENDMODE_BLEND);
+#else
+	    // pixels and pitch will be filled with the texture's values
+	    // in I_FinishUpdate()
+	    argbbuffer = SDL_CreateRGBSurfaceWithFormatFrom(
+                     NULL, w, h, 0, 0, SDL_PIXELFORMAT_ARGB8888);
 #endif
-        SDL_FillRect(argbbuffer, NULL, 0);
     }
 
     if (texture != NULL)
@@ -1688,7 +1697,7 @@ static void SetVideoMode(void)
     // is going to change frequently.
 
     texture = SDL_CreateTexture(renderer,
-                                pixel_format,
+                                SDL_PIXELFORMAT_ARGB8888,
                                 SDL_TEXTUREACCESS_STREAMING,
                                 SCREENWIDTH, SCREENHEIGHT);
 
@@ -1898,9 +1907,6 @@ void I_ReInitGraphics (int reinit)
 	// [crispy] re-set rendering resolution and re-create framebuffers
 	if (reinit & REINIT_FRAMEBUFFERS)
 	{
-		unsigned int rmask, gmask, bmask, amask;
-		int unused_bpp;
-
 		I_GetScreenDimensions();
 
 #ifndef CRISPY_TRUECOLOR
@@ -1913,21 +1919,23 @@ void I_ReInitGraphics (int reinit)
 
 #ifndef CRISPY_TRUECOLOR
 		SDL_FreeSurface(screenbuffer);
-		screenbuffer = SDL_CreateRGBSurface(0,
-				                    SCREENWIDTH, SCREENHEIGHT, 8,
-				                    0, 0, 0, 0);
-#endif
+		screenbuffer = SDL_CreateRGBSurface(
+			0, SCREENWIDTH, SCREENHEIGHT, 8,
+			0, 0, 0, 0);
 
+		// pixels and pitch will be filled with the texture's values
+		// in I_FinishUpdate()
 		SDL_FreeSurface(argbbuffer);
-		SDL_PixelFormatEnumToMasks(pixel_format, &unused_bpp,
-		                           &rmask, &gmask, &bmask, &amask);
-		argbbuffer = SDL_CreateRGBSurface(0,
-		                                  SCREENWIDTH, SCREENHEIGHT, 32,
-		                                  rmask, gmask, bmask, amask);
-#ifndef CRISPY_TRUECOLOR
+		argbbuffer = SDL_CreateRGBSurfaceWithFormatFrom(
+			NULL, SCREENWIDTH, SCREENHEIGHT, 0, 0, SDL_PIXELFORMAT_ARGB8888);
+
 		// [crispy] re-set the framebuffer pointer
 		I_VideoBuffer = screenbuffer->pixels;
 #else
+		SDL_FreeSurface(argbbuffer);
+		argbbuffer = SDL_CreateRGBSurfaceWithFormat(
+			0, SCREENWIDTH, SCREENHEIGHT, 32, SDL_PIXELFORMAT_ARGB8888);
+
 		I_VideoBuffer = argbbuffer->pixels;
 #endif
 		V_RestoreBuffer();
@@ -1968,7 +1976,7 @@ void I_ReInitGraphics (int reinit)
 		SDL_SetHint(SDL_HINT_RENDER_SCALE_QUALITY, "nearest");
 
 		texture = SDL_CreateTexture(renderer,
-		                            pixel_format,
+		                            SDL_PIXELFORMAT_ARGB8888,
 		                            SDL_TEXTUREACCESS_STREAMING,
 		                            SCREENWIDTH, SCREENHEIGHT);
 
@@ -2075,7 +2083,7 @@ void I_RenderReadPixels(byte **data, int *w, int *h, int *p)
 	// already contains the scene that we actually want to capture.
 	if (crispy->post_rendering_hook)
 	{
-		SDL_RenderCopy(renderer, crispy->smoothscaling ? texture_upscaled : texture, NULL, NULL);
+		SDL_RenderCopy(renderer, smooth_pixel_scaling ? texture_upscaled : texture, NULL, NULL);
 		SDL_RenderPresent(renderer);
 	}
 
@@ -2100,6 +2108,7 @@ void I_BindVideoVariables(void)
     M_BindIntVariable("video_display",             &video_display);
     M_BindIntVariable("aspect_ratio_correct",      &aspect_ratio_correct);
     M_BindIntVariable("integer_scaling",           &integer_scaling);
+    M_BindIntVariable("smooth_pixel_scaling",      &smooth_pixel_scaling);
     M_BindIntVariable("vga_porch_flash",           &vga_porch_flash);
     M_BindIntVariable("startup_delay",             &startup_delay);
     M_BindIntVariable("fullscreen_width",          &fullscreen_width);
@@ -2116,82 +2125,8 @@ void I_BindVideoVariables(void)
 }
 
 #ifdef CRISPY_TRUECOLOR
-const pixel_t I_BlendAdd (const pixel_t bg, const pixel_t fg)
-{
-	uint32_t r, g, b;
-
-	if ((r = (fg & rmask) + (bg & rmask)) > rmask) r = rmask;
-	if ((g = (fg & gmask) + (bg & gmask)) > gmask) g = gmask;
-	if ((b = (fg & bmask) + (bg & bmask)) > bmask) b = bmask;
-
-	return amask | r | g | b;
-}
-
-// [crispy] http://stereopsis.com/doubleblend.html
-const pixel_t I_BlendDark (const pixel_t bg, const int d)
-{
-	const uint32_t ag = (bg & 0xff00ff00) >> 8;
-	const uint32_t rb =  bg & 0x00ff00ff;
-
-	uint32_t sag = d * ag;
-	uint32_t srb = d * rb;
-
-	sag = sag & 0xff00ff00;
-	srb = (srb >> 8) & 0x00ff00ff;
-
-	return amask | sag | srb;
-}
-
-// [crispy] Main overlay blending function
-const pixel_t I_BlendOver (const pixel_t bg, const pixel_t fg, const int amount)
-{
-	const uint32_t r = ((amount * (fg & rmask) + (0xff - amount) * (bg & rmask)) >> 8) & rmask;
-	const uint32_t g = ((amount * (fg & gmask) + (0xff - amount) * (bg & gmask)) >> 8) & gmask;
-	const uint32_t b = ((amount * (fg & bmask) + (0xff - amount) * (bg & bmask)) >> 8) & bmask;
-
-	return amask | r | g | b;
-}
-
-// [crispy] TRANMAP blending emulation, used for Doom
-const pixel_t I_BlendOverTranmap (const pixel_t bg, const pixel_t fg)
-{
-	return I_BlendOver(bg, fg, 0xA8); // 168 (66% opacity)
-}
-
-// [crispy] TINTTAB blending emulation, used for Heretic and Hexen
-const pixel_t I_BlendOverTinttab (const pixel_t bg, const pixel_t fg)
-{
-	return I_BlendOver(bg, fg, 0x60); // 96 (38% opacity)
-}
-
-// [crispy] More opaque ("Alt") TINTTAB blending emulation, used for Hexen's MF_ALTSHADOW drawing
-const pixel_t I_BlendOverAltTinttab (const pixel_t bg, const pixel_t fg)
-{
-	return I_BlendOver(bg, fg, 0x8E); // 142 (56% opacity)
-}
-
-// [crispy] More opaque XLATAB blending emulation, used for Strife
-const pixel_t I_BlendOverXlatab (const pixel_t bg, const pixel_t fg)
-{
-	return I_BlendOver(bg, fg, 0xC0); // 192 (75% opacity)
-}
-
-// [crispy] Less opaque ("Alt") XLATAB blending emulation, used for Strife
-const pixel_t I_BlendOverAltXlatab (const pixel_t bg, const pixel_t fg)
-{
-	return I_BlendOver(bg, fg, 0x40); // 64 (25% opacity)
-}
-
-const pixel_t (*blendfunc) (const pixel_t fg, const pixel_t bg) = I_BlendOverTranmap;
-
 const pixel_t I_MapRGB (const uint8_t r, const uint8_t g, const uint8_t b)
 {
-/*
-	return amask |
-	        (((r * rmask) >> 8) & rmask) |
-	        (((g * gmask) >> 8) & gmask) |
-	        (((b * bmask) >> 8) & bmask);
-*/
 	return SDL_MapRGB(argbbuffer->format, r, g, b);
 }
 #endif
