@@ -21,6 +21,7 @@
 #define __I_VIDEO__
 
 #include "doomtype.h"
+#include "i_truecolor.h"
 #include "m_fixed.h" // [crispy] fixed_t
 #include "crispy.h"
 
@@ -100,6 +101,7 @@ void I_StartFrame (void);
 
 void I_StartTic (void);
 
+void I_UpdateFracTic (void); // [crispy]
 void I_StartDisplay (void); // [crispy]
 
 // Enable the loading disk image displayed when reading from disk.
@@ -119,6 +121,7 @@ extern int screen_height;
 extern int fullscreen;
 extern int aspect_ratio_correct;
 extern int integer_scaling;
+extern int smooth_pixel_scaling;
 extern int vga_porch_flash;
 extern int force_software_renderer;
 
@@ -133,4 +136,4 @@ extern unsigned int joywait;
 extern int usemouse;
 
 
-#endif
+#endif
\ No newline at end of file
