@@ -232,6 +232,14 @@ int joybnextweapon = -1;
 int joybmenu = -1;
 int joybautomap = -1;
 
+int joybuseartifact = -1;
+int joybinvleft = -1;
+int joybinvright = -1;
+
+int joybflyup = -1;
+int joybflydown = -1;
+int joybflycenter = -1;
+
 // Control whether if a mouse button is double clicked, it acts like 
 // "use" has been pressed
 
@@ -317,6 +325,14 @@ void M_BindHereticControls(void)
     M_BindIntVariable("mouseb_invright", &mousebinvright);
     M_BindIntVariable("mouseb_useartifact", &mousebuseartifact);
 
+    M_BindIntVariable("joyb_invleft", &joybinvleft);
+    M_BindIntVariable("joyb_invright", &joybinvright);
+    M_BindIntVariable("joyb_useartifact", &joybuseartifact);
+
+    M_BindIntVariable("joyb_flyup", &joybflyup);
+    M_BindIntVariable("joyb_flydown", &joybflydown);
+    M_BindIntVariable("joyb_flycenter", &joybflycenter);
+
     M_BindIntVariable("key_arti_quartz",        &key_arti_quartz);
     M_BindIntVariable("key_arti_urn",           &key_arti_urn);
     M_BindIntVariable("key_arti_bomb",          &key_arti_bomb);
