@@ -24,6 +24,7 @@
 #include "i_system.h"
 #include "i_timer.h"
 #include "m_argv.h"
+#include "m_misc.h"
 
 #include "net_common.h"
 #include "net_io.h"
@@ -469,7 +470,7 @@ void NET_OpenLog(void)
     p = M_CheckParmWithArgs("-netlog", 1);
     if (p > 0)
     {
-        net_debug = fopen(myargv[p + 1], "w");
+        net_debug = M_fopen(myargv[p + 1], "w");
         if (net_debug == NULL)
         {
             I_Error("Failed to open %s to write debug log.", myargv[p + 1]);
