@@ -83,7 +83,6 @@ void BindCompatibilityVariables(void)
         M_BindIntVariable("crispy_secretmessage",   &crispy->secretmessage);
         M_BindIntVariable("crispy_smoothlight",     &crispy->smoothlight);
         M_BindIntVariable("crispy_smoothmap",       &crispy->smoothmap);
-        M_BindIntVariable("crispy_smoothscaling",   &crispy->smoothscaling);
         M_BindIntVariable("crispy_soundfix",        &crispy->soundfix);
         M_BindIntVariable("crispy_soundfull",       &crispy->soundfull);
         M_BindIntVariable("crispy_soundmono",       &crispy->soundmono);
@@ -103,6 +102,9 @@ void BindCompatibilityVariables(void)
         M_BindIntVariable("crispy_automapstats",    &crispy->automapstats);
         M_BindIntVariable("crispy_bobfactor",       &crispy->bobfactor);
         M_BindIntVariable("crispy_centerweapon",    &crispy->centerweapon);
+        M_BindIntVariable("crispy_crosshair",       &crispy->crosshair);
+        M_BindIntVariable("crispy_crosshairtype",   &crispy->crosshairtype);
+        M_BindIntVariable("crispy_crosshaircolor",  &crispy->crosshaircolor);
         M_BindIntVariable("crispy_defaultskill",    &crispy->defaultskill);
         M_BindIntVariable("crispy_fpslimit",        &crispy->fpslimit);
         M_BindIntVariable("crispy_freelook",        &crispy->freelook_hh);
@@ -111,8 +113,9 @@ void BindCompatibilityVariables(void)
         M_BindIntVariable("crispy_leveltime",       &crispy->leveltime);
         M_BindIntVariable("crispy_playercoords",    &crispy->playercoords);
         M_BindIntVariable("crispy_secretmessage",   &crispy->secretmessage);
-        M_BindIntVariable("crispy_smoothscaling",   &crispy->smoothscaling);
         M_BindIntVariable("crispy_soundmono",       &crispy->soundmono);
+        M_BindIntVariable("crispy_lvlwpnsnd",       &crispy->lvlwpnsnd);
+        M_BindIntVariable("crispy_translucency",    &crispy->translucency);
         M_BindIntVariable("crispy_uncapped",        &crispy->uncapped);
         M_BindIntVariable("crispy_vsync",           &crispy->vsync);
         M_BindIntVariable("crispy_widescreen",      &crispy->widescreen);
@@ -123,13 +126,16 @@ void BindCompatibilityVariables(void)
         M_BindIntVariable("vanilla_demo_limit",     &vanilla_demo_limit);
         M_BindIntVariable("crispy_bobfactor",       &crispy->bobfactor);
         M_BindIntVariable("crispy_centerweapon",    &crispy->centerweapon);
+        M_BindIntVariable("crispy_crosshair",       &crispy->crosshair);
+        M_BindIntVariable("crispy_crosshairtype",   &crispy->crosshairtype);
+        M_BindIntVariable("crispy_crosshaircolor",  &crispy->crosshaircolor);
         M_BindIntVariable("crispy_defaultskill",    &crispy->defaultskill);
         M_BindIntVariable("crispy_fpslimit",        &crispy->fpslimit);
         M_BindIntVariable("crispy_freelook",        &crispy->freelook_hh);
         M_BindIntVariable("crispy_hires",           &crispy->hires);
         M_BindIntVariable("crispy_playercoords",    &crispy->playercoords);
-        M_BindIntVariable("crispy_smoothscaling",   &crispy->smoothscaling);
         M_BindIntVariable("crispy_soundmono",       &crispy->soundmono);
+        M_BindIntVariable("crispy_translucency",    &crispy->translucency);
         M_BindIntVariable("crispy_uncapped",        &crispy->uncapped);
         M_BindIntVariable("crispy_vsync",           &crispy->vsync);
         M_BindIntVariable("crispy_widescreen",      &crispy->widescreen);
@@ -154,7 +160,6 @@ void BindCompatibilityVariables(void)
         M_BindIntVariable("crispy_playercoords",    &crispy->playercoords);
         M_BindIntVariable("crispy_smoothlight",     &crispy->smoothlight);
         M_BindIntVariable("crispy_smoothmap",       &crispy->smoothmap);
-        M_BindIntVariable("crispy_smoothscaling",   &crispy->smoothscaling);
         M_BindIntVariable("crispy_soundfix",        &crispy->soundfix);
         M_BindIntVariable("crispy_soundfull",       &crispy->soundfull);
         M_BindIntVariable("crispy_soundmono",       &crispy->soundmono);
