@@ -15,7 +15,15 @@
 #ifndef SETUP_JOYSTICK_H
 #define SETUP_JOYSTICK_H
 
+
+#include "i_joystick.h"
+
+
 extern int joystick_index;
+extern int joystick_physical_buttons[NUM_VIRTUAL_BUTTONS];
+extern int use_gamepad;
+extern int gamepad_type;
+
 
 void ConfigJoystick(void *widget, void *user_data);
 void BindJoystickVariables(void);
