@@ -75,6 +75,15 @@
 #define GAMMALVL3	"Gamma correction level 3"
 #define GAMMALVL4	"Gamma correction level 4"
 // [crispy] intermediate gamma levels
+#define GAMMALVL050	"Gamma correction level -4"
+#define GAMMALVL055	"Gamma correction level -3.6"
+#define GAMMALVL060	"Gamma correction level -3.2"
+#define GAMMALVL065	"Gamma correction level -2.8"
+#define GAMMALVL070	"Gamma correction level -2.4"
+#define GAMMALVL075	"Gamma correction level -2.0"
+#define GAMMALVL080	"Gamma correction level -1.6"
+#define GAMMALVL085	"Gamma correction level -1.2"
+#define GAMMALVL090	"Gamma correction level -0.8"
 #define GAMMALVL05	"Gamma correction level 0.5"
 #define GAMMALVL15	"Gamma correction level 1.5"
 #define GAMMALVL25	"Gamma correction level 2.5"
