@@ -48,6 +48,7 @@
 #include "f_finale.h"
 #include "f_wipe.h"
 
+#include "a11y.h" // [crispy] A11Y
 #include "m_argv.h"
 #include "m_config.h"
 #include "m_controls.h"
@@ -224,9 +225,14 @@ void D_Display (void)
     
     if (crispy->uncapped)
     {
-        I_StartDisplay();
-        G_FastResponder();
-        G_PrepTiccmd();
+        I_UpdateFracTic();
+
+        if (!automapactive || crispy->automapoverlay)
+        {
+            I_StartDisplay();
+            G_FastResponder();
+            G_PrepTiccmd();
+        }
     }
 
     // change the view size if needed
@@ -505,6 +511,7 @@ void D_BindVariables(void)
     M_BindIntVariable("show_talk",              &dialogshowtext);
     M_BindIntVariable("screensize",             &screenblocks);
     M_BindIntVariable("snd_channels",           &snd_channels);
+    M_BindIntVariable("a11y_sector_lighting",   &a11y_sector_lighting); // [crispy]
     M_BindIntVariable("vanilla_savegame_limit", &vanilla_savegame_limit);
     M_BindIntVariable("vanilla_demo_limit",     &vanilla_demo_limit);
     M_BindIntVariable("show_endoom",            &show_endoom);
@@ -544,7 +551,7 @@ void D_BindVariables(void)
     M_BindIntVariable("crispy_playercoords",    &crispy->playercoords);
     M_BindIntVariable("crispy_smoothlight",     &crispy->smoothlight);
     M_BindIntVariable("crispy_smoothmap",       &crispy->smoothmap);
-    M_BindIntVariable("crispy_smoothscaling",   &crispy->smoothscaling);
+    M_BindIntVariable("crispy_smoothscaling",   &smooth_pixel_scaling);
     M_BindIntVariable("crispy_soundfix",        &crispy->soundfix);
     M_BindIntVariable("crispy_soundfull",       &crispy->soundfull);
     M_BindIntVariable("crispy_soundmono",       &crispy->soundmono);
@@ -1697,7 +1704,8 @@ void D_DoomMain (void)
     // @category obscure
     // @vanilla
     //
-    // Set Rogue playtesting mode (godmode, noclip toggled by backspace)
+    // Set Rogue playtesting mode
+    // (god mode; no cliping mode toggled by backspace).
     //
 
     workparm = M_CheckParm ("-work");
@@ -2113,7 +2121,7 @@ void D_DoomMain (void)
     // // @arg <n>
     // // @vanilla
     // //
-    // // Start playing on episode n (1-4)
+    // // Start playing episode n (1-4).
     // //
 
     // p = M_CheckParmWithArgs("-episode", 1);
