@@ -47,6 +47,7 @@
 #include "hu_stuff.h"
 #include "st_stuff.h"
 #include "am_map.h"
+#include "p_extsaveg.h" // [crispy] for extended savegame information
 
 // Needs access to LFB.
 #include "v_video.h"
@@ -555,7 +556,15 @@ void G_BuildTiccmd (ticcmd_t* cmd, int maketic)
         tspeed = 2;             // slow turn 
     else 
         tspeed = speed;
-    
+
+    // [crispy] add quick 180° reverse
+    if (gamekeydown[key_reverse] || mousebuttons[mousebreverse])
+    {
+        angle += ANG180 >> FRACBITS;
+        gamekeydown[key_reverse] = false;
+        mousebuttons[mousebreverse] = false;
+    }
+
     // [crispy] toggle "always run"
     if (gamekeydown[key_toggleautorun])
     {
@@ -2086,6 +2095,9 @@ void G_DoLoadGame (boolean userload)
     if (!P_ReadSaveGameEOF())
         I_Error ("Bad savegame");
 
+    // [crispy] read more extended savegame data
+    P_ReadExtendedSaveGameData();
+
     fclose(save_stream);
     
     if (setsizeneeded)
@@ -2207,6 +2219,9 @@ void G_DoSaveGame (char *path)
 
     P_WriteSaveGameEOF();
 
+    // [crispy] write extended savegame data
+    P_WriteExtendedSaveGameData();
+
     // [crispy] unconditionally disable savegame and demo limits
     /*
     // Enforce the same savegame size limit as in Vanilla Doom, 
