@@ -864,8 +864,8 @@ static void M_DrawSaveLoadBottomLine(void)
         struct stat st;
         char filedate[32];
 
-        stat(P_SaveGameFile(itemOn), &st);
-
+        if (M_stat(P_SaveGameFile(itemOn), &st) == 0)
+        {
 // [FG] suppress the most useless compiler warning ever
 #if defined(__GNUC__)
 #pragma GCC diagnostic push
@@ -876,6 +876,7 @@ static void M_DrawSaveLoadBottomLine(void)
 #pragma GCC diagnostic pop
 #endif
         M_WriteText(ORIGWIDTH/2-M_StringWidth(filedate)/2, y, filedate);
+        }
     }
 }
 
@@ -1511,7 +1512,7 @@ static void M_DrawCrispness1(void)
     M_DrawCrispnessSeparator(crispness_sep_rendering, "Rendering");
     M_DrawCrispnessItem(crispness_hires, "High Resolution Rendering", crispy->hires, true);
     M_DrawCrispnessMultiItem(crispness_widescreen, "Aspect Ratio", multiitem_widescreen, crispy->widescreen, aspect_ratio_correct == 1);
-    M_DrawCrispnessItem(crispness_smoothscaling, "Smooth Pixel Scaling", crispy->smoothscaling, !force_software_renderer);
+    M_DrawCrispnessItem(crispness_smoothscaling, "Smooth Pixel Scaling", smooth_pixel_scaling, !force_software_renderer);
     M_DrawCrispnessItem(crispness_uncapped, "Uncapped Framerate", crispy->uncapped, true);
     M_DrawCrispnessNumericItem(crispness_fpslimit, "Framerate Limit", crispy->fpslimit, "None", crispy->uncapped, "35");
     M_DrawCrispnessItem(crispness_vsync, "Enable VSync", crispy->vsync, !force_software_renderer);
@@ -2699,7 +2700,7 @@ boolean M_Responder (event_t* ev)
         {
             M_StartControlPanel ();
             currentMenu = &SoundDef;
-            itemOn = sfx_vol;
+            itemOn = currentMenu->lastOn; // [crispy] remember cursor position
             S_StartSound(NULL, sfx_swtchn);
             return true;
         }
