@@ -209,6 +209,10 @@ boolean P_TeleportMove(mobj_t*  thing, fixed_t  x, fixed_t  y)
     thing->y = y;
     thing->z = tmfloorz; // haleyjd 09/15/10: [STRIFE] Rogue added a z-set here
 
+    // [AM] Don't interpolate mobjs that pass
+    //      through teleporters
+    thing->interp = false;
+
     P_SetThingPosition (thing);
 
     return true;
@@ -953,10 +957,6 @@ fixed_t		attackrange;
 
 fixed_t		aimslope;
 
-// slopes to top and bottom of target
-extern fixed_t	topslope;
-extern fixed_t	bottomslope;	
-
 
 //
 // PTR_AimTraverse
