@@ -27,6 +27,7 @@
 #include "m_misc.h"
 #include "p_local.h"
 #include "p_saveg.h"
+#include "a11y.h" // [crispy] A11Y
 
 // State.
 #include "doomstat.h"
@@ -72,7 +73,9 @@ char *P_SaveGameFile(int slot)
         filename = malloc(filename_size);
     }
 
-    DEH_snprintf(basename, 32, SAVEGAMENAME "%d.dsg", slot);
+    // [crispy] changed to Strife savegame file name,
+    // used by M_DrawSaveLoadBottomLine to show savegame date and time
+    DEH_snprintf(basename, 32, "strfsav%d.ssg/name", slot);
 
     M_snprintf(filename, filename_size, "%s%s", savegamedir, basename);
 
@@ -1524,6 +1527,9 @@ static void saveg_read_lightflash_t(lightflash_t *str)
 
     // int mintime;
     str->mintime = saveg_read32();
+
+    if (!a11y_sector_lighting)
+        str->sector->rlightlevel = str->maxlight;
 }
 
 static void saveg_write_lightflash_t(lightflash_t *str)
@@ -1579,6 +1585,10 @@ static void saveg_read_strobe_t(strobe_t *str)
 
     // int brighttime;
     str->brighttime = saveg_read32();
+
+    // [crispy] Ensure maxlight among competing thinkers. 
+    if (!a11y_sector_lighting && str->sector->rlightlevel < str->maxlight)
+        str->sector->rlightlevel = str->maxlight;
 }
 
 static void saveg_write_strobe_t(strobe_t *str)
@@ -1628,6 +1638,9 @@ static void saveg_read_glow_t(glow_t *str)
 
     // int direction;
     str->direction = saveg_read32();
+
+    if (!a11y_sector_lighting)
+        str->sector->rlightlevel = str->maxlight;
 }
 
 static void saveg_write_glow_t(glow_t *str)
@@ -1881,6 +1894,7 @@ void P_UnArchiveWorld (void)
         sec->floorpic = saveg_read16();
         //sec->ceilingpic = saveg_read16(); [STRIFE] not saved
         sec->lightlevel = saveg_read16();
+        sec->rlightlevel = sec->lightlevel; // [crispy] A11Y
         sec->special = saveg_read16();          // needed?
         //sec->tag = saveg_read16();              // needed? [STRIFE] not saved
         sec->specialdata = 0;
