@@ -209,6 +209,13 @@ static const inline pixel_t drawtinttab (const pixel_t dest, const pixel_t sourc
 #else
 {return I_BlendOverTinttab(dest, pal_color[source]);}
 #endif
+// V_DrawTLPatch Translated Option (translucent patch, color-translated)
+static const inline pixel_t drawtrtinttab (const pixel_t dest, const pixel_t source)
+#ifndef CRISPY_TRUECOLOR
+{return tinttable[dest+(dp_translation[source]<<8)];}
+#else
+{return I_BlendOverTinttab(dest, pal_color[dp_translation[source]]);}
+#endif
 // V_DrawAltTLPatch (translucent patch, no coloring or color-translation are used)
 static const inline pixel_t drawalttinttab (const pixel_t dest, const pixel_t source)
 #ifndef CRISPY_TRUECOLOR
@@ -216,6 +223,13 @@ static const inline pixel_t drawalttinttab (const pixel_t dest, const pixel_t so
 #else
 {return I_BlendOverAltTinttab(dest, pal_color[source]);}
 #endif
+// V_DrawAltTLPatch Translated Option (translucent patch, color-translated)
+static const inline pixel_t drawtralttinttab (const pixel_t dest, const pixel_t source)
+#ifndef CRISPY_TRUECOLOR
+{return tinttable[(dest<<8)+dp_translation[source]];}
+#else
+{return I_BlendOverAltTinttab(dest, pal_color[dp_translation[source]]);}
+#endif
 // V_DrawXlaPatch (translucent patch, no coloring or color-translation are used)
 static const inline pixel_t drawxlatab (const pixel_t dest, const pixel_t source)
 #ifndef CRISPY_TRUECOLOR
@@ -227,6 +241,8 @@ static const inline pixel_t drawxlatab (const pixel_t dest, const pixel_t source
 // [crispy] array of function pointers holding the different rendering functions
 typedef const pixel_t drawpatchpx_t (const pixel_t dest, const pixel_t source);
 static drawpatchpx_t *const drawpatchpx_a[2][2] = {{drawpatchpx11, drawpatchpx10}, {drawpatchpx01, drawpatchpx00}};
+static drawpatchpx_t *const drawtlpatchpx_a[2] = {drawtrtinttab, drawtinttab};
+static drawpatchpx_t *const drawalttlpatchpx_a[2] = {drawtralttinttab, drawalttinttab};
 
 static fixed_t dx, dxi, dy, dyi;
 
@@ -520,8 +536,8 @@ void V_DrawTLPatch(int x, int y, patch_t * patch)
     byte *source;
     int w;
 
-    // [crispy] translucent patch, no coloring or color-translation are used
-    drawpatchpx_t *const drawpatchpx = drawtinttab;
+    // [crispy] translucent patch with optional color-translation used
+    drawpatchpx_t *const drawpatchpx = drawtlpatchpx_a[!dp_translation];
 
     y -= SHORT(patch->topoffset);
     x -= SHORT(patch->leftoffset);
@@ -634,8 +650,8 @@ void V_DrawAltTLPatch(int x, int y, patch_t * patch)
     byte *source;
     int w;
 
-    // [crispy] translucent patch, no coloring or color-translation are used
-    drawpatchpx_t *const drawpatchpx = drawalttinttab;
+    // [crispy] translucent patch with optional color-translation used
+    drawpatchpx_t *const drawpatchpx = drawalttlpatchpx_a[!dp_translation];
 
     y -= SHORT(patch->topoffset);
     x -= SHORT(patch->leftoffset);
@@ -801,28 +817,59 @@ void V_DrawScaledBlock(int x, int y, int width, int height, byte *src)
 
     x += WIDESCREENDELTA; // [crispy] horizontal widescreen offset
 
-#ifdef RANGECHECK
-    if (x < 0
-     || x + width > SCREENWIDTH
-     || y < 0
-     || y + height > SCREENWIDTH)
+    const int rx = x << crispy->hires;
+    const int ry = y << crispy->hires;
+    const int rw = width << crispy->hires;
+    const int rh = height << crispy->hires;
+
+    int dx0 = rx;
+    int dy0 = ry;
+    int dx1 = rx + rw;
+    int dy1 = ry + rh;
+
+    // Clipping
+    if (dx0 < 0)
     {
-	I_Error ("Bad V_DrawScaledBlock");
+        dx0 = 0;
     }
-#endif
-
-    V_MarkRect (x, y, width, height);
-
-    dest = dest_screen + (y << crispy->hires) * SCREENWIDTH + (x << crispy->hires);
-
-    for (i = 0; i < (height << crispy->hires); i++)
+    if (dy0 < 0)
     {
-        for (j = 0; j < (width << crispy->hires); j++)
+        dy0 = 0;
+    }
+    if (dx1 > SCREENWIDTH)
+    {
+        dx1 = SCREENWIDTH;
+    }
+    if (dy1 > SCREENHEIGHT)
+    {
+        dy1 = SCREENHEIGHT;
+    }
+
+    const int dw = dx1 - dx0;
+    const int dh = dy1 - dy0;
+
+    if (dw <= 0 || dh <= 0)
+    {
+        return;
+    }
+
+    const int xoff = dx0 - rx;
+    const int yoff = dy0 - ry;
+
+    dest = dest_screen + dy0 * SCREENWIDTH + dx0;
+
+    for (i = 0; i < dh; ++i)
+    {
+        const int src_y = (i + yoff) >> crispy->hires;
+        const byte *src_row = src + src_y * width;
+
+        for (j = 0; j < dw; ++j)
         {
+            const int src_x = (j + xoff) >> crispy->hires;
 #ifndef CRISPY_TRUECOLOR
-            *(dest + i * SCREENWIDTH + j) = *(src + (i >> crispy->hires) * width + (j >> crispy->hires));
+            dest[i * SCREENWIDTH + j] = src_row[src_x];
 #else
-            *(dest + i * SCREENWIDTH + j) = pal_color[*(src + (i >> crispy->hires) * width + (j >> crispy->hires))];
+            dest[i * SCREENWIDTH + j] = pal_color[src_row[src_x]];
 #endif
         }
     }
@@ -886,25 +933,13 @@ void V_DrawBox(int x, int y, int w, int h, int c)
     V_DrawVertLine(x, y, h, c);
     V_DrawVertLine(x+w-1, y, h, c);
 }
-
-//
-// Draw a "raw" screen (lump containing raw data to blit directly
-// to the screen)
-//
-
-void V_CopyScaledBuffer(pixel_t *dest, byte *src, size_t size)
+ 
+static void V_DrawRawScreen(byte *raw, int size)
 {
-    int i, j, index;
+    int width = size / ORIGHEIGHT;
+    int x = ((SCREENWIDTH >> crispy->hires) - width) / 2 - WIDESCREENDELTA;
 
-#ifdef RANGECHECK
-    if (size > ORIGWIDTH * ORIGHEIGHT)
-    {
-        I_Error("Bad V_CopyScaledBuffer");
-    }
-#endif
-
-    // [crispy] Fill pillarboxes in widescreen mode. Needs to be two separate
-    // pillars to allow for Heretic finale vertical scrolling.
+    // [crispy] pillar boxing
     if (SCREENWIDTH != NONWIDEWIDTH)
     {
         V_DrawFilledBox(0, 0, WIDESCREENDELTA << crispy->hires, SCREENHEIGHT, 0);
@@ -912,43 +947,7 @@ void V_CopyScaledBuffer(pixel_t *dest, byte *src, size_t size)
                         WIDESCREENDELTA << crispy->hires, SCREENHEIGHT, 0);
     }
 
-    index = ((size / ORIGWIDTH) << crispy->hires) * SCREENWIDTH - 1;
-
-    if (size % ORIGWIDTH)
-    {
-        // [crispy] Handles starting in the middle of a row.
-        index += ((size % ORIGWIDTH) + WIDESCREENDELTA) << crispy->hires;
-    }
-    else
-    {
-        index -= WIDESCREENDELTA << crispy->hires;
-    }
-
-    while (size--)
-    {
-        for (i = 0; i <= crispy->hires; i++)
-        {
-            for (j = 0; j <= crispy->hires; j++)
-            {
-#ifndef CRISPY_TRUECOLOR
-                *(dest + index - (j * SCREENWIDTH) - i) = *(src + size);
-#else
-                *(dest + index - (j * SCREENWIDTH) - i) = pal_color[src[size]];
-#endif
-            }
-        }
-        if (size % ORIGWIDTH == 0)
-        {
-            index -= 2 * (WIDESCREENDELTA << crispy->hires)
-                     + crispy->hires * SCREENWIDTH;
-        }
-        index -= 1 + crispy->hires;
-    }
-}
- 
-void V_DrawRawScreen(byte *raw)
-{
-    V_CopyScaledBuffer(dest_screen, raw, ORIGWIDTH * ORIGHEIGHT);
+    V_DrawScaledBlock(x, 0, width, ORIGHEIGHT, raw);
 }
 
 // [crispy] For Heretic and Hexen widescreen support of replacement TITLE,
@@ -960,14 +959,16 @@ void V_DrawFullscreenRawOrPatch(lumpindex_t index)
 
     patch = W_CacheLumpNum(index, PU_CACHE);
 
-    if (W_LumpLength(index) == ORIGWIDTH * ORIGHEIGHT)
-    {
-        V_DrawRawScreen((byte*)patch);
-    }
-    else if ((SHORT(patch->height) == 200) && (SHORT(patch->width) >= 320))
+    int size = W_LumpLength(index);
+
+    if (V_IsPatchLump(index))
     {
         V_DrawPatchFullScreen(patch, false);
     }
+    else if (size % 200 == 0)
+    {
+        V_DrawRawScreen((byte*)patch, size);
+    }
     else
     {
         I_Error("Invalid fullscreen graphic.");
@@ -1467,3 +1468,63 @@ void V_DrawMouseSpeedBox(int speed)
     }
 }
 
+// [FG] check if the lump can be a Doom patch
+// taken from PrBoom+ prboom2/src/r_patch.c:L350-L390
+
+boolean V_IsPatchLump(const int lump)
+{
+    int size;
+    int width, height;
+    const patch_t *patch;
+    boolean result;
+
+    if (lump < 0)
+        return false;
+
+    size = W_LumpLength(lump);
+
+    // Minimum length of a valid Doom patch
+    if (size < 13)
+    {
+        return false;
+    }
+
+    patch = (const patch_t *) W_CacheLumpNum(lump, PU_CACHE);
+
+    // [FG] detect patches in PNG format early
+    if (!memcmp(patch, "\211PNG\r\n\032\n", 8))
+    {
+        return false;
+    }
+
+    width = SHORT(patch->width);
+    height = SHORT(patch->height);
+
+    result = (height > 0 && height <= 16384 && width > 0 && width <= 16384 &&
+              width < size / 4);
+
+    if (result)
+    {
+        // The dimensions seem like they might be valid for a patch, so
+        // check the column directory for extra security. All columns
+        // must begin after the column directory, and none of them must
+        // point past the end of the patch.
+        int x;
+
+        for (x = 0; x < width; x++)
+        {
+            unsigned int ofs = LONG(patch->columnofs[x]);
+
+            // Need one byte for an empty column
+            // (but there's patches that don't know that!)
+            if (ofs < (unsigned int) width * 4 + 8 ||
+                ofs >= (unsigned int) size)
+            {
+                result = false;
+                break;
+            }
+        }
+    }
+
+    return result;
+}
