@@ -39,6 +39,18 @@ typedef struct
                    void *buffer, size_t buffer_len);
 } wad_file_class_t;
 
+
+extern wad_file_class_t stdc_wad_file;
+
+#ifdef _WIN32
+extern wad_file_class_t win32_wad_file;
+#endif
+
+#ifdef HAVE_MMAP
+extern wad_file_class_t posix_wad_file;
+#endif
+
+
 struct _wad_file_s
 {
     // Class of this file.
