@@ -35,22 +35,6 @@
 
 #include "w_wad.h"
 
-typedef PACKED_STRUCT (
-{
-    // Should be "IWAD" or "PWAD".
-    char		identification[4];
-    int			numlumps;
-    int			infotableofs;
-}) wadinfo_t;
-
-
-typedef PACKED_STRUCT (
-{
-    int			filepos;
-    int			size;
-    char		name[8];
-}) filelump_t;
-
 //
 // GLOBALS
 //
