@@ -30,6 +30,22 @@
 // TYPES
 //
 
+typedef PACKED_STRUCT (
+{
+    // Should be "IWAD" or "PWAD".
+    char        identification[4];
+    int         numlumps;
+    int         infotableofs;
+}) wadinfo_t;
+
+
+typedef PACKED_STRUCT (
+{
+    int         filepos;
+    int         size;
+    char        name[8];
+}) filelump_t;
+
 //
 // WADFILE I/O related stuff.
 //
