@@ -88,21 +88,21 @@ static const short code_page_to_unicode[] = CODE_PAGE_TO_UNICODE;
 static const SDL_Color ega_colors[] =
 {
     {0x00, 0x00, 0x00, 0xff},          // 0: Black
-    {0x00, 0x00, 0xa8, 0xff},          // 1: Blue
-    {0x00, 0xa8, 0x00, 0xff},          // 2: Green
-    {0x00, 0xa8, 0xa8, 0xff},          // 3: Cyan
-    {0xa8, 0x00, 0x00, 0xff},          // 4: Red
-    {0xa8, 0x00, 0xa8, 0xff},          // 5: Magenta
-    {0xa8, 0x54, 0x00, 0xff},          // 6: Brown
-    {0xa8, 0xa8, 0xa8, 0xff},          // 7: Grey
-    {0x54, 0x54, 0x54, 0xff},          // 8: Dark grey
-    {0x54, 0x54, 0xfe, 0xff},          // 9: Bright blue
-    {0x54, 0xfe, 0x54, 0xff},          // 10: Bright green
-    {0x54, 0xfe, 0xfe, 0xff},          // 11: Bright cyan
-    {0xfe, 0x54, 0x54, 0xff},          // 12: Bright red
-    {0xfe, 0x54, 0xfe, 0xff},          // 13: Bright magenta
-    {0xfe, 0xfe, 0x54, 0xff},          // 14: Yellow
-    {0xfe, 0xfe, 0xfe, 0xff},          // 15: Bright white
+    {0x00, 0x00, 0xaa, 0xff},          // 1: Blue
+    {0x00, 0xaa, 0x00, 0xff},          // 2: Green
+    {0x00, 0xaa, 0xaa, 0xff},          // 3: Cyan
+    {0xaa, 0x00, 0x00, 0xff},          // 4: Red
+    {0xaa, 0x00, 0xaa, 0xff},          // 5: Magenta
+    {0xaa, 0x55, 0x00, 0xff},          // 6: Brown
+    {0xaa, 0xaa, 0xaa, 0xff},          // 7: Grey
+    {0x55, 0x55, 0x55, 0xff},          // 8: Dark grey
+    {0x55, 0x55, 0xff, 0xff},          // 9: Bright blue
+    {0x55, 0xff, 0x55, 0xff},          // 10: Bright green
+    {0x55, 0xff, 0xff, 0xff},          // 11: Bright cyan
+    {0xff, 0x55, 0x55, 0xff},          // 12: Bright red
+    {0xff, 0x55, 0xff, 0xff},          // 13: Bright magenta
+    {0xff, 0xff, 0x55, 0xff},          // 14: Yellow
+    {0xff, 0xff, 0xff, 0xff},          // 15: Bright white
 };
 
 #ifdef _WIN32
@@ -311,6 +311,8 @@ void TXT_Shutdown(void)
     screendata = NULL;
     SDL_FreeSurface(screenbuffer);
     screenbuffer = NULL;
+    SDL_DestroyRenderer(renderer);
+    SDL_DestroyWindow(TXT_SDLWindow);
     SDL_QuitSubSystem(SDL_INIT_VIDEO);
 }
 
